"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QCommonStyle(QStyle):
    """
    https://doc.qt.io/qt-6/qcommonstyle.html

    **Detailed Description**

    This abstract class implements some of the widget's look and feel that is
    common to all GUI styles provided and shipped as part of Qt.

    Since QCommonStyle inherits **QStyle** , all of its functions are fully
    documented in the **QStyle**  documentation.

    **See also** **QStyle**  and **QProxyStyle** .
    """

    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qcommonstyle.html#QCommonStyle

        **QCommonStyle::QCommonStyle()**

        Constructs a QCommonStyle.
        """
        ...

    def layoutSpacing(
        self,
        control1: "QSizePolicy.ControlType",
        control2: "QSizePolicy.ControlType",
        orientation: QtCore.Qt.Orientation,
        option: typing.Optional["QStyleOption"] = ...,
        widget: typing.Optional[QWidget] = ...,
    ) -> int:
        """
        https://doc.qt.io/qt-6/qcommonstyle.html#layoutSpacing

        **[override virtual] int
        QCommonStyle::layoutSpacing(QSizePolicy::ControlType control1 ,
        QSizePolicy::ControlType control2 , Qt::Orientation orientation , const
        QStyleOption * option = nullptr, const QWidget * widget = nullptr)
        const**

        Reimplements: **QStyle::layoutSpacing(QSizePolicy::ControlType control1,
        QSizePolicy::ControlType control2, Qt::Orientation orientation, const
        QStyleOption *option, const QWidget *widget) const** .
        """
        ...

    def standardIcon(
        self,
        standardIcon: QStyle.StandardPixmap,
        option: typing.Optional["QStyleOption"] = ...,
        widget: typing.Optional[QWidget] = ...,
    ) -> QtGui.QIcon:
        ...

    def generatedIconPixmap(
        self, iconMode: QtGui.QIcon.Mode, pixmap: QtGui.QPixmap, opt: "QStyleOption"
    ) -> QtGui.QPixmap:
        """
        https://doc.qt.io/qt-6/qcommonstyle.html#generatedIconPixmap

        **[override virtual] QPixmap
        QCommonStyle::generatedIconPixmap(QIcon::Mode iconMode , const QPixmap &
        pixmap , const QStyleOption * opt ) const**

        Reimplements: **QStyle::generatedIconPixmap(QIcon::Mode iconMode, const
        QPixmap &pixmap, const QStyleOption *option) const** .
        """
        ...

    def standardPixmap(
        self,
        sp: QStyle.StandardPixmap,
        option: typing.Optional["QStyleOption"] = ...,
        widget: typing.Optional[QWidget] = ...,
    ) -> QtGui.QPixmap:
        """
        https://doc.qt.io/qt-6/qcommonstyle.html#standardPixmap

        **[override virtual] QPixmap
        QCommonStyle::standardPixmap(QStyle::StandardPixmap sp , const
        QStyleOption * option = nullptr, const QWidget * widget = nullptr)
        const**

        Reimplements: **QStyle::standardPixmap(QStyle::StandardPixmap
        standardPixmap, const QStyleOption *option, const QWidget *widget)
        const** .
        """
        ...

    def styleHint(
        self,
        sh: QStyle.StyleHint,
        option: typing.Optional["QStyleOption"] = ...,
        widget: typing.Optional[QWidget] = ...,
        returnData: typing.Optional["QStyleHintReturn"] = ...,
    ) -> int:
        """
        https://doc.qt.io/qt-6/qcommonstyle.html#styleHint

        **[override virtual] int QCommonStyle::styleHint(QStyle::StyleHint sh ,
        const QStyleOption * opt = nullptr, const QWidget * widget = nullptr,
        QStyleHintReturn * hret = nullptr) const**

        Reimplements: **QStyle::styleHint(QStyle::StyleHint hint, const
        QStyleOption *option, const QWidget *widget, QStyleHintReturn
        *returnData) const** .
        """
        ...

    def pixelMetric(
        self,
        m: QStyle.PixelMetric,
        option: typing.Optional["QStyleOption"] = ...,
        widget: typing.Optional[QWidget] = ...,
    ) -> int:
        """
        https://doc.qt.io/qt-6/qcommonstyle.html#pixelMetric

        **[override virtual] int QCommonStyle::pixelMetric(QStyle::PixelMetric m
        , const QStyleOption * opt = nullptr, const QWidget * widget = nullptr)
        const**

        Reimplements: **QStyle::pixelMetric(QStyle::PixelMetric metric, const
        QStyleOption *option, const QWidget *widget) const** .
        """
        ...

    def sizeFromContents(
        self,
        ct: QStyle.ContentsType,
        opt: "QStyleOption",
        contentsSize: QtCore.QSize,
        widget: typing.Optional[QWidget] = ...,
    ) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qcommonstyle.html#sizeFromContents

        **[override virtual] QSize
        QCommonStyle::sizeFromContents(QStyle::ContentsType ct , const
        QStyleOption * opt , const QSize & csz , const QWidget * widget =
        nullptr) const**

        Reimplements: **QStyle::sizeFromContents(QStyle::ContentsType type,
        const QStyleOption *option, const QSize &contentsSize, const QWidget
        *widget) const** .
        """
        ...

    def subControlRect(
        self,
        cc: QStyle.ComplexControl,
        opt: "QStyleOptionComplex",
        sc: QStyle.SubControl,
        widget: typing.Optional[QWidget] = ...,
    ) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qcommonstyle.html#subControlRect

        **[override virtual] QRect
        QCommonStyle::subControlRect(QStyle::ComplexControl cc , const
        QStyleOptionComplex * opt , QStyle::SubControl sc , const QWidget *
        widget = nullptr) const**

        Reimplements: **QStyle::subControlRect(QStyle::ComplexControl control,
        const QStyleOptionComplex *option, QStyle::SubControl subControl, const
        QWidget *widget) const** .
        """
        ...

    def hitTestComplexControl(
        self,
        cc: QStyle.ComplexControl,
        opt: "QStyleOptionComplex",
        pt: QtCore.QPoint,
        widget: typing.Optional[QWidget] = ...,
    ) -> QStyle.SubControl:
        """
        https://doc.qt.io/qt-6/qcommonstyle.html#hitTestComplexControl

        **[override virtual] QStyle::SubControl
        QCommonStyle::hitTestComplexControl(QStyle::ComplexControl cc , const
        QStyleOptionComplex * opt , const QPoint & pt , const QWidget * widget =
        nullptr) const**

        Reimplements: **QStyle::hitTestComplexControl(QStyle::ComplexControl
        control, const QStyleOptionComplex *option, const QPoint &position,
        const QWidget *widget) const** .
        """
        ...

    def drawComplexControl(
        self,
        cc: QStyle.ComplexControl,
        opt: "QStyleOptionComplex",
        p: QtGui.QPainter,
        widget: typing.Optional[QWidget] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qcommonstyle.html#drawComplexControl

        **[override virtual] void
        QCommonStyle::drawComplexControl(QStyle::ComplexControl cc , const
        QStyleOptionComplex * opt , QPainter * p , const QWidget * widget =
        nullptr) const**

        Reimplements: **QStyle::drawComplexControl(QStyle::ComplexControl
        control, const QStyleOptionComplex *option, QPainter *painter, const
        QWidget *widget) const** .
        """
        ...

    def subElementRect(
        self,
        r: QStyle.SubElement,
        opt: "QStyleOption",
        widget: typing.Optional[QWidget] = ...,
    ) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qcommonstyle.html#subElementRect

        **[override virtual] QRect
        QCommonStyle::subElementRect(QStyle::SubElement sr , const QStyleOption
        * opt , const QWidget * widget = nullptr) const**

        Reimplements: **QStyle::subElementRect(QStyle::SubElement element, const
        QStyleOption *option, const QWidget *widget) const** .
        """
        ...

    def drawControl(
        self,
        element: QStyle.ControlElement,
        opt: "QStyleOption",
        p: QtGui.QPainter,
        widget: typing.Optional[QWidget] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qcommonstyle.html#drawControl

        **[override virtual] void
        QCommonStyle::drawControl(QStyle::ControlElement element , const
        QStyleOption * opt , QPainter * p , const QWidget * widget = nullptr)
        const**

        Reimplements: **QStyle::drawControl(QStyle::ControlElement element,
        const QStyleOption *option, QPainter *painter, const QWidget *widget)
        const** .
        """
        ...

    def drawPrimitive(
        self,
        pe: QStyle.PrimitiveElement,
        opt: "QStyleOption",
        p: QtGui.QPainter,
        widget: typing.Optional[QWidget] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qcommonstyle.html#drawPrimitive

        **[override virtual] void
        QCommonStyle::drawPrimitive(QStyle::PrimitiveElement pe , const
        QStyleOption * opt , QPainter * p , const QWidget * widget = nullptr)
        const**

        Reimplements: **QStyle::drawPrimitive(QStyle::PrimitiveElement element,
        const QStyleOption *option, QPainter *painter, const QWidget *widget)
        const** .
        """
        ...

    @typing.overload
    def unpolish(self, widget: QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qcommonstyle.html#unpolish

        **[override virtual] void QCommonStyle::unpolish(QWidget * widget )**

        Reimplements: **QStyle::unpolish** (QWidget *widget).
        """
        ...

    @typing.overload
    def unpolish(self, application: QApplication) -> None:
        """
        https://doc.qt.io/qt-6/qcommonstyle.html#unpolish-1

        **[override virtual] void QCommonStyle::unpolish(QApplication *
        application )**

        Reimplements: **QStyle::unpolish** (QApplication *application).
        """
        ...

    @typing.overload
    def polish(self, widget: QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qcommonstyle.html#polish

        **[override virtual] void QCommonStyle::polish(QPalette & pal )**

        Reimplements: **QStyle::polish** (QPalette &palette).
        """
        ...

    @typing.overload
    def polish(self, app: QApplication) -> None:
        """
        https://doc.qt.io/qt-6/qcommonstyle.html#polish-1

        **[override virtual] void QCommonStyle::polish(QApplication * app )**

        Reimplements: **QStyle::polish** (QApplication *application).
        """
        ...

    @typing.overload
    def polish(self, a0: QtGui.QPalette) -> QtGui.QPalette:
        """
        https://doc.qt.io/qt-6/qcommonstyle.html#polish-2

        **[override virtual] void QCommonStyle::polish(QWidget * widget )**

        Reimplements: **QStyle::polish** (QWidget *widget).
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *
import enum


class QKeySequence(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qkeysequence.html

    **Detailed Description**

    In its most common form, a key sequence describes a combination of keys that
    must be used together to perform some action. Key sequences are used with
    **QAction**  objects to specify which keyboard shortcuts can be used to
    trigger actions.

    Key sequences can be constructed for use as keyboard shortcuts in three
    different ways:

    * For standard shortcuts, a **standard key**  can be used to request the
    platform-specific key sequence associated with each shortcut.
      * For custom
    shortcuts, human-readable strings such as "Ctrl+X" can be used, and these
    can be translated into the appropriate shortcuts for users of different
    languages. Translations are made in the "**QShortcut** " context.
      * For
    hard-coded shortcuts, integer key codes can be specified with a combination
    of values defined by the **Qt::Key**  and **Qt::Modifier**  enum values.
    Each key code consists of a single **Qt::Key**  value and zero or more
    modifiers, such as **Qt::SHIFT** , **Qt::CTRL** , **Qt::ALT**  and
    **Qt::META** .

    For example, **Ctrl P** might be a sequence used as a shortcut for printing
    a document, and can be specified in any of the following ways:

    QKeySequence(QKeySequence::Print);
        QKeySequence(tr("Ctrl+P"));
    QKeySequence(tr("Ctrl+p"));
        QKeySequence(Qt::CTRL | Qt::Key_P);
    QKeySequence(Qt::CTRL + Qt::Key_P); // deprecated

    Note that, for letters, the case used in the specification string does not
    matter. In the above examples, the user does not need to hold down the
    **Shift** key to activate a shortcut specified with "Ctrl+P". However, for
    other keys, the use of **Shift** as an unspecified extra modifier key can
    lead to confusion for users of an application whose keyboards have different
    layouts to those used by the developers. See the **Keyboard Layout Issues**
    section below for more details.

    It is preferable to use standard shortcuts where possible. When creating key
    sequences for non-standard shortcuts, you should use human-readable strings
    in preference to hard-coded integer values.

    QKeySequence objects can be cast to a **QString**  to obtain a human-
    readable translated version of the sequence. Similarly, the **toString** ()
    function produces human-readable strings for use in menus. On macOS, the
    appropriate symbols are used to describe keyboard shortcuts using special
    keys on the Macintosh keyboard.

    An alternative way to specify hard-coded key codes is to use the Unicode
    code point of the character; for example, 'A' gives the same key sequence as
    **Qt::Key_A** .

    **Note:** On macOS, references to "Ctrl", **Qt::CTRL** , **Qt::Key_Control**
    and **Qt::ControlModifier**  correspond to the **Command** keys on the
    Macintosh keyboard, and references to "Meta", **Qt::META** ,
    **Qt::Key_Meta**  and **Qt::MetaModifier**  correspond to the **Control**
    keys. Developers on macOS can use the same shortcut descriptions across all
    platforms, and their applications will automatically work as expected on
    macOS.

    **Standard Shortcuts**

    QKeySequence defines many **standard keyboard shortcuts**  to reduce the
    amount of effort required when setting up actions in a typical application.
    The table below shows some common key sequences that are often used for
    these standard shortcuts by applications on four widely-used platforms. Note
    that on macOS, the **Ctrl** value corresponds to the **Command** keys on the
    Macintosh keyboard, and the **Meta** value corresponds to the **Control**
    keys.

    **StandardKey** WindowsmacOSKDE PlasmaGNOME
    **HelpContents** F1Ctrl+?F1F1
    **WhatsThis** Shift+F1Shift+F1Shift+F1Shift+F1
    OpenCtrl+OCtrl+OCtrl+OCtrl+O
    CloseCtrl+F4, Ctrl+WCtrl+W,
    Ctrl+F4Ctrl+WCtrl+W
    SaveCtrl+SCtrl+SCtrl+SCtrl+S
    QuitCtrl+QCtrl+QCtrl+Q
    **SaveAs** Ctrl+Shift+SCtrl+Shift+S
    NewCtrl+NCtrl+NCtrl+NCtrl+N
    DeleteDelDel, Meta+DDel, Ctrl+DDel, Ctrl+D
    CutCtrl+X, Shift+DelCtrl+X,
    Meta+KCtrl+X, F20, Shift+DelCtrl+X, F20, Shift+Del
    CopyCtrl+C,
    Ctrl+InsCtrl+CCtrl+C, F16, Ctrl+InsCtrl+C, F16, Ctrl+Ins
    PasteCtrl+V,
    Shift+InsCtrl+V, Meta+YCtrl+V, F18, Shift+InsCtrl+V, F18, Shift+Ins
    PreferencesCtrl+,
    UndoCtrl+Z, Alt+BackspaceCtrl+ZCtrl+Z, F14Ctrl+Z, F14
    RedoCtrl+Y, Shift+Ctrl+Z,
    Alt+Shift+BackspaceCtrl+Shift+ZCtrl+Shift+ZCtrl+Shift+Z
    BackAlt+Left,
    BackspaceCtrl+[Alt+LeftAlt+Left
    ForwardAlt+Right,
    Shift+BackspaceCtrl+]Alt+RightAlt+Right
    RefreshF5F5F5Ctrl+R, F5
    **ZoomIn** Ctrl+PlusCtrl+PlusCtrl+PlusCtrl+Plus
    **ZoomOut**
    Ctrl+MinusCtrl+MinusCtrl+MinusCtrl+Minus
    **FullScreen** F11,
    Alt+EnterCtrl+Meta+FF11, Ctrl+Shift+FCtrl+F11
    PrintCtrl+PCtrl+PCtrl+PCtrl+P
    **AddTab** Ctrl+TCtrl+TCtrl+Shift+N,
    Ctrl+TCtrl+T
    **NextChild** Ctrl+Tab, Forward, Ctrl+F6Ctrl+}, Forward,
    Ctrl+TabCtrl+Tab, Forward, Ctrl+CommaCtrl+Tab, Forward
    **PreviousChild**
    Ctrl+Shift+Tab, Back, Ctrl+Shift+F6Ctrl+{, Back,
    Ctrl+Shift+TabCtrl+Shift+Tab, Back, Ctrl+PeriodCtrl+Shift+Tab, Back
    FindCtrl+FCtrl+FCtrl+FCtrl+F
    **FindNext** F3, Ctrl+GCtrl+GF3Ctrl+G, F3
    **FindPrevious** Shift+F3, Ctrl+Shift+GCtrl+Shift+GShift+F3Ctrl+Shift+G,
    Shift+F3
    ReplaceCtrl+H(none)Ctrl+RCtrl+H
    **SelectAll**
    Ctrl+ACtrl+ACtrl+ACtrl+A
    DeselectCtrl+Shift+ACtrl+Shift+A
    BoldCtrl+BCtrl+BCtrl+BCtrl+B
    ItalicCtrl+ICtrl+ICtrl+ICtrl+I
    UnderlineCtrl+UCtrl+UCtrl+UCtrl+U
    **MoveToNextChar** RightRight,
    Meta+FRightRight
    **MoveToPreviousChar** LeftLeft, Meta+BLeftLeft
    **MoveToNextWord** Ctrl+RightAlt+RightCtrl+RightCtrl+Right
    **MoveToPreviousWord** Ctrl+LeftAlt+LeftCtrl+LeftCtrl+Left
    **MoveToNextLine** DownDown, Meta+NDownDown
    **MoveToPreviousLine** UpUp,
    Meta+PUpUp
    **MoveToNextPage** PgDownPgDown, Alt+PgDown, Meta+Down,
    Meta+PgDown, Meta+VPgDownPgDown
    **MoveToPreviousPage** PgUpPgUp, Alt+PgUp,
    Meta+Up, Meta+PgUpPgUpPgUp
    **MoveToStartOfLine** HomeCtrl+Left,
    Meta+LeftHomeHome
    **MoveToEndOfLine** EndCtrl+Right, Meta+RightEnd,
    Ctrl+EEnd, Ctrl+E
    **MoveToStartOfBlock** (none)Alt+Up, Meta+A(none)(none)
    **MoveToEndOfBlock** (none)Alt+Down, Meta+E(none)(none)
    **MoveToStartOfDocument** Ctrl+HomeCtrl+Up, HomeCtrl+HomeCtrl+Home
    **MoveToEndOfDocument** Ctrl+EndCtrl+Down, EndCtrl+EndCtrl+End
    **SelectNextChar** Shift+RightShift+RightShift+RightShift+Right
    **SelectPreviousChar** Shift+LeftShift+LeftShift+LeftShift+Left
    **SelectNextWord**
    Ctrl+Shift+RightAlt+Shift+RightCtrl+Shift+RightCtrl+Shift+Right
    **SelectPreviousWord**
    Ctrl+Shift+LeftAlt+Shift+LeftCtrl+Shift+LeftCtrl+Shift+Left
    **SelectNextLine** Shift+DownShift+DownShift+DownShift+Down
    **SelectPreviousLine** Shift+UpShift+UpShift+UpShift+Up
    **SelectNextPage**
    Shift+PgDownShift+PgDownShift+PgDownShift+PgDown
    **SelectPreviousPage**
    Shift+PgUpShift+PgUpShift+PgUpShift+PgUp
    **SelectStartOfLine**
    Shift+HomeCtrl+Shift+LeftShift+HomeShift+Home
    **SelectEndOfLine**
    Shift+EndCtrl+Shift+RightShift+EndShift+End
    **SelectStartOfBlock**
    (none)Alt+Shift+Up, Meta+Shift+A(none)(none)
    **SelectEndOfBlock**
    (none)Alt+Shift+Down, Meta+Shift+E(none)(none)
    **SelectStartOfDocument**
    Ctrl+Shift+HomeCtrl+Shift+Up, Shift+HomeCtrl+Shift+HomeCtrl+Shift+Home
    **SelectEndOfDocument** Ctrl+Shift+EndCtrl+Shift+Down,
    Shift+EndCtrl+Shift+EndCtrl+Shift+End
    **DeleteStartOfWord**
    Ctrl+BackspaceAlt+BackspaceCtrl+BackspaceCtrl+Backspace
    **DeleteEndOfWord** Ctrl+Del(none)Ctrl+DelCtrl+Del
    **DeleteEndOfLine**
    (none)(none)Ctrl+KCtrl+K
    **DeleteCompleteLine** (none)(none)Ctrl+UCtrl+U
    **InsertParagraphSeparator** EnterEnterEnterEnter
    **InsertLineSeparator**
    Shift+EnterMeta+Enter, Meta+OShift+EnterShift+Enter
    Backspace(none)Meta+H(none)(none)
    CancelEscapeEscape, Ctrl+.EscapeEscape

    Note that, since the key sequences used for the standard shortcuts differ
    between platforms, you still need to test your shortcuts on each platform to
    ensure that you do not unintentionally assign the same key sequence to many
    actions.

    **Keyboard Layout Issues**

    Many key sequence specifications are chosen by developers based on the
    layout of certain types of keyboard, rather than choosing keys that
    represent the first letter of an action's name, such as **Ctrl S**
    ("Ctrl+S") or **Ctrl C** ("Ctrl+C"). Additionally, because certain symbols
    can only be entered with the help of modifier keys on certain keyboard
    layouts, key sequences intended for use with one keyboard layout may map to
    a different key, map to no keys at all, or require an additional modifier
    key to be used on different keyboard layouts.

    For example, the shortcuts, **Ctrl plus** and **Ctrl minus** , are often
    used as shortcuts for zoom operations in graphics applications, and these
    may be specified as "Ctrl++" and "Ctrl+-" respectively. However, the way
    these shortcuts are specified and interpreted depends on the keyboard
    layout. Users of Norwegian keyboards will note that the **+** and **-** keys
    are not adjacent on the keyboard, but will still be able to activate both
    shortcuts without needing to press the **Shift** key. However, users with
    British keyboards will need to hold down the **Shift** key to enter the
    **+** symbol, making the shortcut effectively the same as "Ctrl+Shift+=".

    Although some developers might resort to fully specifying all the modifiers
    they use on their keyboards to activate a shortcut, this will also result in
    unexpected behavior for users of different keyboard layouts.

    For example, a developer using a British keyboard may decide to specify
    "Ctrl+Shift+=" as the key sequence in order to create a shortcut that
    coincidentally behaves in the same way as **Ctrl plus**. However, the **=**
    key needs to be accessed using the **Shift** key on Norwegian keyboard,
    making the required shortcut effectively **Ctrl Shift Shift =** (an
    impossible key combination).

    As a result, both human-readable strings and hard-coded key codes can both
    be problematic to use when specifying a key sequence that can be used on a
    variety of different keyboard layouts. Only the use of **standard
    shortcuts**  guarantees that the user will be able to use the shortcuts that
    the developer intended.

    Despite this, we can address this issue by ensuring that human-readable
    strings are used, making it possible for translations of key sequences to be
    made for users of different languages. This approach will be successful for
    users whose keyboards have the most typical layout for the language they are
    using.

    **GNU Emacs Style Key Sequences**

    Key sequences similar to those used in **GNU Emacs** , allowing up to four
    key codes, can be created by using the multiple argument constructor, or by
    passing a human-readable string of comma-separated key sequences.

    For example, the key sequence, **Ctrl X** followed by **Ctrl C** , can be
    specified using either of the following ways:

    QKeySequence(tr("Ctrl+X, Ctrl+C"));
        QKeySequence(Qt::CTRL | Qt::Key_X,
    Qt::CTRL | Qt::Key_C);
        QKeySequence(Qt::CTRL + Qt::Key_X, Qt::CTRL +
    Qt::Key_C); // deprecated

    **Warning:** A **QApplication**  instance must have been constructed before
    a QKeySequence is created; otherwise, your application may crash.

    **See also** **QShortcut** .
    """

    class StandardKey(enum.Enum):
        UnknownKey: QKeySequence = ...
        HelpContents: QKeySequence = ...
        WhatsThis: QKeySequence = ...
        Open: QKeySequence = ...
        Close: QKeySequence = ...
        Save: QKeySequence = ...
        New: QKeySequence = ...
        Delete: QKeySequence = ...
        Cut: QKeySequence = ...
        Copy: QKeySequence = ...
        Paste: QKeySequence = ...
        Undo: QKeySequence = ...
        Redo: QKeySequence = ...
        Back: QKeySequence = ...
        Forward: QKeySequence = ...
        Refresh: QKeySequence = ...
        ZoomIn: QKeySequence = ...
        ZoomOut: QKeySequence = ...
        Print: QKeySequence = ...
        AddTab: QKeySequence = ...
        NextChild: QKeySequence = ...
        PreviousChild: QKeySequence = ...
        Find: QKeySequence = ...
        FindNext: QKeySequence = ...
        FindPrevious: QKeySequence = ...
        Replace: QKeySequence = ...
        SelectAll: QKeySequence = ...
        Bold: QKeySequence = ...
        Italic: QKeySequence = ...
        Underline: QKeySequence = ...
        MoveToNextChar: QKeySequence = ...
        MoveToPreviousChar: QKeySequence = ...
        MoveToNextWord: QKeySequence = ...
        MoveToPreviousWord: QKeySequence = ...
        MoveToNextLine: QKeySequence = ...
        MoveToPreviousLine: QKeySequence = ...
        MoveToNextPage: QKeySequence = ...
        MoveToPreviousPage: QKeySequence = ...
        MoveToStartOfLine: QKeySequence = ...
        MoveToEndOfLine: QKeySequence = ...
        MoveToStartOfBlock: QKeySequence = ...
        MoveToEndOfBlock: QKeySequence = ...
        MoveToStartOfDocument: QKeySequence = ...
        MoveToEndOfDocument: QKeySequence = ...
        SelectNextChar: QKeySequence = ...
        SelectPreviousChar: QKeySequence = ...
        SelectNextWord: QKeySequence = ...
        SelectPreviousWord: QKeySequence = ...
        SelectNextLine: QKeySequence = ...
        SelectPreviousLine: QKeySequence = ...
        SelectNextPage: QKeySequence = ...
        SelectPreviousPage: QKeySequence = ...
        SelectStartOfLine: QKeySequence = ...
        SelectEndOfLine: QKeySequence = ...
        SelectStartOfBlock: QKeySequence = ...
        SelectEndOfBlock: QKeySequence = ...
        SelectStartOfDocument: QKeySequence = ...
        SelectEndOfDocument: QKeySequence = ...
        DeleteStartOfWord: QKeySequence = ...
        DeleteEndOfWord: QKeySequence = ...
        DeleteEndOfLine: QKeySequence = ...
        InsertParagraphSeparator: QKeySequence = ...
        InsertLineSeparator: QKeySequence = ...
        SaveAs: QKeySequence = ...
        Preferences: QKeySequence = ...
        Quit: QKeySequence = ...
        FullScreen: QKeySequence = ...
        Deselect: QKeySequence = ...
        DeleteCompleteLine: QKeySequence = ...
        Backspace: QKeySequence = ...
        Cancel: QKeySequence = ...

    class SequenceMatch(enum.Enum):
        NoMatch: QKeySequence = ...
        PartialMatch: QKeySequence = ...
        ExactMatch: QKeySequence = ...

    class SequenceFormat(enum.Enum):
        NativeText: QKeySequence = ...
        PortableText: QKeySequence = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qkeysequence.html#QKeySequence

        **QKeySequence::QKeySequence()**

        Constructs an empty key sequence.
        """
        ...

    @typing.overload
    def __init__(self, ks: "QKeySequence") -> None:
        """
        https://doc.qt.io/qt-6/qkeysequence.html#QKeySequence-1

        **QKeySequence::QKeySequence(const QString & key ,
        QKeySequence::SequenceFormat format = NativeText)**

        Creates a key sequence from the **key** string, based on **format**.

        For example "Ctrl+O" gives CTRL+'O'. The strings "Ctrl", "Shift", "Alt"
        and "Meta" are recognized, as well as their translated equivalents in
        the "**QShortcut** " context (using **QObject::tr** ()).

        Up to four key codes may be entered by separating them with commas, e.g.
        "Alt+X,Ctrl+S,Q".

        This constructor is typically used with **tr** (), so that shortcut keys
        can be replaced in translations:

        **QMenu**  *file = new **QMenu** (this);
        file->addAction(tr("&Open..."), this, SLOT(open()),
        **QKeySequence** (tr("Ctrl+O", "File|Open")));

        Note the "File|Open" translator comment. It is by no means necessary,
        but it provides some context for the human translator.
        """
        ...

    @typing.overload
    def __init__(self, key: "QKeySequence.StandardKey") -> None:
        """
        https://doc.qt.io/qt-6/qkeysequence.html#QKeySequence-2

        **QKeySequence::QKeySequence(int k1 , int k2 = 0, int k3 = 0, int k4 =
        0)**

        Constructs a key sequence with up to 4 keys **k1** , **k2** , **k3** and
        **k4**.

        The key codes are listed in **Qt::Key**  and can be combined with
        modifiers (see **Qt::Modifier** ) such as **Qt::SHIFT** , **Qt::CTRL** ,
        **Qt::ALT** , or **Qt::META** .
        """
        ...

    @typing.overload
    def __init__(self, key: str, format: "QKeySequence.SequenceFormat" = ...) -> None:
        """
        https://doc.qt.io/qt-6/qkeysequence.html#QKeySequence-3

        **QKeySequence::QKeySequence(QKeyCombination k1 , QKeyCombination k2 =
        QKeyCombination::fromCombined(0), QKeyCombination k3 =
        QKeyCombination::fromCombined(0), QKeyCombination k4 =
        QKeyCombination::fromCombined(0))**

        Constructs a key sequence with up to 4 keys **k1** , **k2** , **k3** and
        **k4**.

        **See also** **QKeyCombination** .
        """
        ...

    @typing.overload
    def __init__(
        self, k1: int, key2: int = ..., key3: int = ..., key4: int = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qkeysequence.html#QKeySequence-4

        **QKeySequence::QKeySequence(const QKeySequence & keysequence )**

        Copy constructor. Makes a copy of **keysequence**.
        """
        ...

    @typing.overload
    def __init__(
        self,
        k1: QtCore.QKeyCombination,
        key2: QtCore.QKeyCombination = ...,
        key3: QtCore.QKeyCombination = ...,
        key4: QtCore.QKeyCombination = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qkeysequence.html#QKeySequence-5

        **QKeySequence::QKeySequence(QKeySequence::StandardKey key )**

        Constructs a QKeySequence object for the given **key**. The result will
        depend on the currently running platform.

        The resulting object will be based on the first element in the list of
        key bindings for the **key**.
        """
        ...

    @typing.overload
    def __init__(self, variant: typing.Any) -> None:
        """
        https://doc.qt.io/qt-6/qkeysequence.html#QKeySequence

        **QKeySequence::QKeySequence()**

        Constructs an empty key sequence.
        """
        ...

    def __hash__(self) -> int:
        ...

    @staticmethod
    def listToString(
        list: typing.Iterable[
            typing.Union["QKeySequence", "QKeySequence.StandardKey", str, int]
        ],
        format: "QKeySequence.SequenceFormat" = ...,
    ) -> str:
        """
        https://doc.qt.io/qt-6/qkeysequence.html#listToString

        **[static, since 5.1] QString QKeySequence::listToString(const
        QList<QKeySequence> & list , QKeySequence::SequenceFormat format =
        PortableText)**

        Return a string representation of **list** based on **format**.

        This function was introduced in Qt 5.1.

        **See also** **toString** () and **listFromString** ().
        """
        ...

    @staticmethod
    def listFromString(
        str: str, format: "QKeySequence.SequenceFormat" = ...
    ) -> typing.List["QKeySequence"]:
        """
        https://doc.qt.io/qt-6/qkeysequence.html#listFromString

        **[static, since 5.1] QList<QKeySequence>
        QKeySequence::listFromString(const QString & str ,
        QKeySequence::SequenceFormat format = PortableText)**

        Return a list of **QKeySequence**  from the string **str** based on
        **format**.

        This function was introduced in Qt 5.1.

        **See also** **fromString** () and **listToString** ().
        """
        ...

    @staticmethod
    def keyBindings(key: "QKeySequence.StandardKey") -> typing.List["QKeySequence"]:
        """
        https://doc.qt.io/qt-6/qkeysequence.html#keyBindings

        **[static] QList<QKeySequence>
        QKeySequence::keyBindings(QKeySequence::StandardKey key )**

        Returns a list of key bindings for the given **key**. The result of
        calling this function will vary based on the target platform. The first
        element of the list indicates the primary shortcut for the given
        platform. If the result contains more than one result, these can be
        considered alternative shortcuts on the same platform for the given
        **key**.
        """
        ...

    @staticmethod
    def fromString(
        str: str, format: "QKeySequence.SequenceFormat" = ...
    ) -> "QKeySequence":
        """
        https://doc.qt.io/qt-6/qkeysequence.html#fromString

        **[static] QKeySequence QKeySequence::fromString(const QString & str ,
        QKeySequence::SequenceFormat format = PortableText)**

        Return a **QKeySequence**  from the string **str** based on **format**.

        **See also** **toString** ().
        """
        ...

    def toString(self, format: "QKeySequence.SequenceFormat" = ...) -> str:
        """
        https://doc.qt.io/qt-6/qkeysequence.html#toString

        **QString QKeySequence::toString(QKeySequence::SequenceFormat format =
        PortableText) const**

        Return a string representation of the key sequence, based on **format**.

        For example, the value **Qt::CTRL** +**Qt::Key_O**  results in "Ctrl+O".
        If the key sequence has multiple key codes, each is separated by commas
        in the string returned, such as "Alt+X, Ctrl+Y, Z". The strings, "Ctrl",
        "Shift", etc. are translated using **QObject::tr** () in the
        "**QShortcut** " context.

        If the key sequence has no keys, an empty string is returned.

        On macOS, the string returned resembles the sequence that is shown in
        the menu bar if **format** is **QKeySequence::NativeText** ; otherwise,
        the string uses the "portable" format, suitable for writing to a file.

        **See also** **fromString** ().
        """
        ...

    def swap(self, other: "QKeySequence") -> None:
        """
        https://doc.qt.io/qt-6/qkeysequence.html#swap

        **void QKeySequence::swap(QKeySequence & other )**

        Swaps key sequence **other** with this key sequence. This operation is
        very fast and never fails.
        """
        ...

    def isDetached(self) -> bool:
        ...

    def __getitem__(self, i: int) -> QtCore.QKeyCombination:
        ...

    @staticmethod
    def mnemonic(text: str) -> "QKeySequence":
        """
        https://doc.qt.io/qt-6/qkeysequence.html#mnemonic

        **[static] QKeySequence QKeySequence::mnemonic(const QString & text )**

        Returns the shortcut key sequence for the mnemonic in **text** , or an
        empty key sequence if no mnemonics are found.

        For example, mnemonic("E&xit") returns `Qt::ALT+Qt::Key_X`,
        mnemonic("&Quit") returns `ALT+Key_Q`, and mnemonic("Quit") returns an
        empty **QKeySequence** .

        We provide a **list of common mnemonics**  in English. At the time of
        writing, Microsoft and Open Group do not appear to have issued
        equivalent recommendations for other languages.
        """
        ...

    def matches(
        self, seq: typing.Union["QKeySequence", "QKeySequence.StandardKey", str, int]
    ) -> "QKeySequence.SequenceMatch":
        """
        https://doc.qt.io/qt-6/qkeysequence.html#matches

        **QKeySequence::SequenceMatch QKeySequence::matches(const QKeySequence &
        seq ) const**

        Matches the sequence with **seq**. Returns **ExactMatch**  if
        successful, **PartialMatch**  if **seq** matches incompletely, and
        **NoMatch**  if the sequences have nothing in common. Returns
        **NoMatch**  if **seq** is shorter.
        """
        ...

    def isEmpty(self) -> bool:
        """
        https://doc.qt.io/qt-6/qkeysequence.html#isEmpty

        **bool QKeySequence::isEmpty() const**

        Returns `true` if the key sequence is empty; otherwise returns false.
        """
        ...

    def __len__(self) -> int:
        ...

    def count(self) -> int:
        """
        https://doc.qt.io/qt-6/qkeysequence.html#count

        **int QKeySequence::count() const**

        Returns the number of keys in the key sequence. The maximum is 4.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
import datetime
from PyQt6.QtCore import *


class QDate(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qdate.html

    **Detailed Description**

    A QDate object represents a particular day, regardless of calendar, locale
    or other settings used when creating it or supplied by the system. It can
    report the year, month and day of the month that represent the day with
    respect to the proleptic Gregorian calendar or any calendar supplied as a
    **QCalendar**  object. QDate objects should be passed by value rather than
    by reference to const; they simply package `qint64`.

    A QDate object is typically created by giving the year, month, and day
    numbers explicitly. Note that QDate interprets year numbers less than 100 as
    presented, i.e., as years 1 through 99, without adding any offset. The
    static function **currentDate** () creates a QDate object containing the
    date read from the system clock. An explicit date can also be set using
    **setDate** (). The **fromString** () function returns a QDate given a
    string and a date format which is used to interpret the date within the
    string.

    The **year** (), **month** (), and **day** () functions provide access to
    the year, month, and day numbers. When more than one of these values is
    needed, it is more efficient to call **QCalendar::partsFromDate** (), to
    save repeating (potentially expensive) calendrical calculations.

    Also, **dayOfWeek** () and **dayOfYear** () functions are provided. The same
    information is provided in textual format by **toString** (). **QLocale**
    can map the day numbers to names, **QCalendar**  can map month numbers to
    names.

    QDate provides a full set of operators to compare two QDate objects where
    smaller means earlier, and larger means later.

    You can increment (or decrement) a date by a given number of days using
    **addDays** (). Similarly you can use **addMonths** () and **addYears** ().
    The **daysTo** () function returns the number of days between two dates.

    The **daysInMonth** () and **daysInYear** () functions return how many days
    there are in this date's month and year, respectively. The **isLeapYear** ()
    function indicates whether a date is in a leap year. **QCalendar**  can also
    supply this information, in some cases more conveniently.

    **Remarks**

    **Note:** All conversion to and from string formats is done using the C
    locale. For localized conversions, see **QLocale** .

    In the Gregorian calendar, there is no year 0. Dates in that year are
    considered invalid. The year -1 is the year "1 before Christ" or "1 before
    common era." The day before 1 January 1 CE, QDate(1, 1, 1), is 31 December 1
    BCE, QDate(-1, 12, 31). Various other calendars behave similarly; see
    **QCalendar::hasYearZero** ().

    **Range of Valid Dates**

    Dates are stored internally as a Julian Day number, an integer count of
    every day in a contiguous range, with 24 November 4714 BCE in the Gregorian
    calendar being Julian Day 0 (1 January 4713 BCE in the Julian calendar). As
    well as being an efficient and accurate way of storing an absolute date, it
    is suitable for converting a date into other calendar systems such as
    Hebrew, Islamic or Chinese. The Julian Day number can be obtained using
    **QDate::toJulianDay** () and can be set using **QDate::fromJulianDay** ().

    The range of Julian Day numbers that QDate can represent is, for technical
    reasons, limited to between -784350574879 and 784354017364, which means from
    before 2 billion BCE to after 2 billion CE. This is more than seven times as
    wide as the range of dates a **QDateTime**  can represent.

    **See also** **QTime** , **QDateTime** , **QCalendar** ,
    **QDateTime::YearRange** , **QDateEdit** , **QDateTimeEdit** , and
    **QCalendarWidget** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qdate.html#QDate-1

        **QDate::QDate()**

        Constructs a null date. Null dates are invalid.

        **See also** **isNull** () and **isValid** ().
        """
        ...

    @typing.overload
    def __init__(self, y: int, m: int, d: int) -> None:
        """
        https://doc.qt.io/qt-6/qdate.html#QDate-2

        **QDate::QDate(int y , int m , int d )**

        Constructs a date with year **y** , month **m** and day **d**.

        The date is understood in terms of the Gregorian calendar. If the
        specified date is invalid, the date is not set and **isValid** ()
        returns `false`.

        **Warning:** Years 1 to 99 are interpreted as is. Year 0 is invalid.

        **See also** **isValid** () and **QCalendar::dateFromParts** ().
        """
        ...

    @typing.overload
    def __init__(self, y: int, m: int, d: int, cal: QCalendar) -> None:
        """
        https://doc.qt.io/qt-6/qdate.html#QDate-1

        **QDate::QDate()**

        Constructs a null date. Null dates are invalid.

        **See also** **isNull** () and **isValid** ().
        """
        ...

    @typing.overload
    def __init__(self, a0: "QDate") -> None:
        """
        https://doc.qt.io/qt-6/qdate.html#QDate-1

        **QDate::QDate()**

        Constructs a null date. Null dates are invalid.

        **See also** **isNull** () and **isValid** ().
        """
        ...

    def daysTo(self, d: typing.Union["QDate", datetime.date]) -> int:
        """
        https://doc.qt.io/qt-6/qdate.html#daysTo

        **qint64 QDate::daysTo(QDate d ) const**

        Returns the number of days from this date to **d** (which is negative if
        **d** is earlier than this date).

        Returns 0 if either date is invalid.

        Example:

        QDate d1(1995, 5, 17);  // May 17, 1995
            QDate d2(1995, 5, 20);  //
        May 20, 1995
            d1.daysTo(d2);          // returns 3
            d2.daysTo(d1);
        // returns -3

        **See also** **addDays** ().
        """
        ...

    @typing.overload
    def endOfDay(
        self, spec: Qt.TimeSpec = ..., offsetSeconds: int = ...
    ) -> "QDateTime":
        ...

    @typing.overload
    def endOfDay(self, zone: "QTimeZone") -> "QDateTime":
        ...

    @typing.overload
    def startOfDay(
        self, spec: Qt.TimeSpec = ..., offsetSeconds: int = ...
    ) -> "QDateTime":
        ...

    @typing.overload
    def startOfDay(self, zone: "QTimeZone") -> "QDateTime":
        ...

    def getDate(self) -> typing.Tuple[int, int, int]:
        """
        https://doc.qt.io/qt-6/qdate.html#getDate

        **void QDate::getDate(int * year , int * month , int * day ) const**

        Extracts the date's year, month, and day, and assigns them to * **year**
        , * **month** , and * **day**. The pointers may be null.

        Returns 0 if the date is invalid.

        **Note:** In Qt versions prior to 5.7, this function is marked as
        non-`const`.

        **See also** **year** (), **month** (), **day** (), **isValid** (), and
        **QCalendar::partsFromDate** ().
        """
        ...

    @typing.overload
    def setDate(self, year: int, month: int, date: int) -> bool:
        """
        https://doc.qt.io/qt-6/qdate.html#setDate

        **bool QDate::setDate(int year , int month , int day )**

        Sets this to represent the date, in the Gregorian calendar, with the
        given **year** , **month** and **day** numbers. Returns true if the
        resulting date is valid, otherwise it sets this to represent an invalid
        date and returns false.

        **See also** **isValid** () and **QCalendar::dateFromParts** ().
        """
        ...

    @typing.overload
    def setDate(self, year: int, month: int, day: int, cal: QCalendar) -> bool:
        """
        https://doc.qt.io/qt-6/qdate.html#setDate-1

        **[since 5.14] bool QDate::setDate(int year , int month , int day ,
        QCalendar cal )**

        Sets this to represent the date, in the given calendar **cal** , with
        the given **year** , **month** and **day** numbers. Returns true if the
        resulting date is valid, otherwise it sets this to represent an invalid
        date and returns false.

        This function was introduced in Qt 5.14.

        **See also** **isValid** () and **QCalendar::dateFromParts** ().
        """
        ...

    def toJulianDay(self) -> int:
        """
        https://doc.qt.io/qt-6/qdate.html#toJulianDay

        **qint64 QDate::toJulianDay() const**

        Converts the date to a Julian day.

        **See also** **fromJulianDay** ().
        """
        ...

    @staticmethod
    def fromJulianDay(jd: int) -> "QDate":
        """
        https://doc.qt.io/qt-6/qdate.html#fromJulianDay

        **[static] QDate QDate::fromJulianDay(qint64 jd )**

        Converts the Julian day **jd** to a **QDate** .

        **See also** **toJulianDay** ().
        """
        ...

    @staticmethod
    def isLeapYear(year: int) -> bool:
        """
        https://doc.qt.io/qt-6/qdate.html#isLeapYear

        **[static] bool QDate::isLeapYear(int year )**

        Returns `true` if the specified **year** is a leap year in the Gregorian
        calendar; otherwise returns `false`.

        **See also** **QCalendar::isLeapYear** ().
        """
        ...

    @typing.overload
    @staticmethod
    def fromString(string: str, format: Qt.DateFormat = ...) -> "QDate":
        """
        https://doc.qt.io/qt-6/qdate.html#fromString

        **[static] QDate QDate::fromString(const QString & string ,
        Qt::DateFormat format = Qt::TextDate)**

        Returns the **QDate**  represented by the **string** , using the
        **format** given, or an invalid date if the string cannot be parsed.

        Note for **Qt::TextDate** : only English month names (e.g. "Jan" in
        short form or "January" in long form) are recognized.

        **See also** **toString** () and **QLocale::toDate** ().
        """
        ...

    @typing.overload
    @staticmethod
    def fromString(string: str, format: str, cal: QCalendar = ...) -> "QDate":
        """
        https://doc.qt.io/qt-6/qdate.html#fromString-1

        **[static, since 6.0] QDate QDate::fromString(QStringView string ,
        Qt::DateFormat format = Qt::TextDate)**

        This is an overloaded function.

        This function was introduced in Qt 6.0.
        """
        ...

    @staticmethod
    def currentDate() -> "QDate":
        """
        https://doc.qt.io/qt-6/qdate.html#currentDate

        **[static] QDate QDate::currentDate()**

        Returns the current date, as reported by the system clock.

        **See also** **QTime::currentTime** () and
        **QDateTime::currentDateTime** ().
        """
        ...

    @typing.overload
    def addYears(self, years: int) -> "QDate":
        """
        https://doc.qt.io/qt-6/qdate.html#addYears

        **QDate QDate::addYears(int nyears , QCalendar cal ) const**

        Returns a **QDate**  object containing a date **nyears** later than the
        date of this object (or earlier if **nyears** is negative).

        Uses **cal** as calendar, if supplied, else the Gregorian calendar.

        **Note:** If the ending day/month combination does not exist in the
        resulting year (e.g., for the Gregorian calendar, if the date was Feb 29
        and the final year is not a leap year), this function will return a date
        that is the latest valid date in the given month (in the example, Feb
        28).

        **See also** **addDays** () and **addMonths** ().
        """
        ...

    @typing.overload
    def addYears(self, years: int, cal: QCalendar) -> "QDate":
        """
        https://doc.qt.io/qt-6/qdate.html#addYears-1

        **QDate QDate::addYears(int nyears ) const**

        This is an overloaded function.
        """
        ...

    @typing.overload
    def addMonths(self, months: int) -> "QDate":
        """
        https://doc.qt.io/qt-6/qdate.html#addMonths

        **QDate QDate::addMonths(int nmonths , QCalendar cal ) const**

        Returns a **QDate**  object containing a date **nmonths** later than the
        date of this object (or earlier if **nmonths** is negative).

        Uses **cal** as calendar, if supplied, else the Gregorian calendar.

        **Note:** If the ending day/month combination does not exist in the
        resulting month/year, this function will return a date that is the
        latest valid date in the selected month.

        **See also** **addDays** () and **addYears** ().
        """
        ...

    @typing.overload
    def addMonths(self, months: int, cal: QCalendar) -> "QDate":
        """
        https://doc.qt.io/qt-6/qdate.html#addMonths-1

        **QDate QDate::addMonths(int nmonths ) const**

        This is an overloaded function.
        """
        ...

    def addDays(self, days: int) -> "QDate":
        """
        https://doc.qt.io/qt-6/qdate.html#addDays

        **QDate QDate::addDays(qint64 ndays ) const**

        Returns a **QDate**  object containing a date **ndays** later than the
        date of this object (or earlier if **ndays** is negative).

        Returns a null date if the current date is invalid or the new date is
        out of range.

        **See also** **addMonths** (), **addYears** (), and **daysTo** ().
        """
        ...

    @typing.overload
    def toString(self, format: Qt.DateFormat = ...) -> str:
        """
        https://doc.qt.io/qt-6/qdate.html#toString-1

        **QString QDate::toString(Qt::DateFormat format = Qt::TextDate) const**

        This is an overloaded function.

        Returns the date as a string. The **format** parameter determines the
        format of the string.

        If the **format** is **Qt::TextDate** , the string is formatted in the
        default way. The day and month names will be in English. An example of
        this formatting is "Sat May 20 1995". For localized formatting, see
        **QLocale::toString** ().

        If the **format** is **Qt::ISODate** , the string format corresponds to
        the ISO 8601 extended specification for representations of dates and
        times, taking the form yyyy-MM-dd, where yyyy is the year, MM is the
        month of the year (between 01 and 12), and dd is the day of the month
        between 01 and 31.

        If the **format** is **Qt::RFC2822Date** , the string is formatted in an
        **RFC 2822**  compatible way. An example of this formatting is "20 May
        1995".

        If the date is invalid, an empty string will be returned.

        **Warning:** The **Qt::ISODate**  format is only valid for years in the
        range 0 to 9999.

        **See also** **fromString** () and **QLocale::toString** ().
        """
        ...

    @typing.overload
    def toString(self, format: str, cal: QCalendar = ...) -> str:
        """
        https://doc.qt.io/qt-6/qdate.html#toString-1

        **QString QDate::toString(Qt::DateFormat format = Qt::TextDate) const**

        This is an overloaded function.

        Returns the date as a string. The **format** parameter determines the
        format of the string.

        If the **format** is **Qt::TextDate** , the string is formatted in the
        default way. The day and month names will be in English. An example of
        this formatting is "Sat May 20 1995". For localized formatting, see
        **QLocale::toString** ().

        If the **format** is **Qt::ISODate** , the string format corresponds to
        the ISO 8601 extended specification for representations of dates and
        times, taking the form yyyy-MM-dd, where yyyy is the year, MM is the
        month of the year (between 01 and 12), and dd is the day of the month
        between 01 and 31.

        If the **format** is **Qt::RFC2822Date** , the string is formatted in an
        **RFC 2822**  compatible way. An example of this formatting is "20 May
        1995".

        If the date is invalid, an empty string will be returned.

        **Warning:** The **Qt::ISODate**  format is only valid for years in the
        range 0 to 9999.

        **See also** **fromString** () and **QLocale::toString** ().
        """
        ...

    def weekNumber(self) -> typing.Tuple[int, int]:
        """
        https://doc.qt.io/qt-6/qdate.html#weekNumber

        **int QDate::weekNumber(int * yearNumber = nullptr) const**

        Returns the ISO 8601 week number (1 to 53).

        Returns 0 if the date is invalid. Otherwise, returns the week number for
        the date. If **yearNumber** is not `nullptr` (its default), stores the
        year as * **yearNumber**.

        In accordance with ISO 8601, each week falls in the year to which most
        of its days belong, in the Gregorian calendar. As ISO 8601's week starts
        on Monday, this is the year in which the week's Thursday falls. Most
        years have 52 weeks, but some have 53.

        **Note:** * **yearNumber** is not always the same as **year** (). For
        example, 1 January 2000 has week number 52 in the year 1999, and 31
        December 2002 has week number 1 in the year 2003.

        **See also** **isValid** ().
        """
        ...

    @typing.overload
    def daysInYear(self) -> int:
        """
        https://doc.qt.io/qt-6/qdate.html#daysInYear

        **int QDate::daysInYear(QCalendar cal ) const**

        Returns the number of days in the year for this date.

        Uses **cal** as calendar if supplied, else the Gregorian calendar (for
        which the result is 365 or 366). Returns 0 if the date is invalid.

        **See also** **day** (), **daysInMonth** (), **QCalendar::daysInYear**
        (), and **QCalendar::maximumMonthsInYear** ().
        """
        ...

    @typing.overload
    def daysInYear(self, cal: QCalendar) -> int:
        """
        https://doc.qt.io/qt-6/qdate.html#daysInYear-1

        **int QDate::daysInYear() const**

        This is an overloaded function.
        """
        ...

    @typing.overload
    def daysInMonth(self) -> int:
        """
        https://doc.qt.io/qt-6/qdate.html#daysInMonth

        **int QDate::daysInMonth(QCalendar cal ) const**

        Returns the number of days in the month for this date.

        Uses **cal** as calendar if supplied, else the Gregorian calendar (for
        which the result ranges from 28 to 31). Returns 0 if the date is
        invalid.

        **See also** **day** (), **daysInYear** (), **QCalendar::daysInMonth**
        (), **QCalendar::maximumDaysInMonth** (), and
        **QCalendar::minimumDaysInMonth** ().
        """
        ...

    @typing.overload
    def daysInMonth(self, cal: QCalendar) -> int:
        """
        https://doc.qt.io/qt-6/qdate.html#daysInMonth-1

        **int QDate::daysInMonth() const**

        This is an overloaded function.
        """
        ...

    @typing.overload
    def dayOfYear(self) -> int:
        """
        https://doc.qt.io/qt-6/qdate.html#dayOfYear

        **int QDate::dayOfYear(QCalendar cal ) const**

        Returns the day of the year (1 for the first day) for this date.

        Uses **cal** as calendar if supplied, else the Gregorian calendar.
        Returns 0 if either the date or the first day of its year is invalid.

        **See also** **day** (), **dayOfWeek** (), and **QCalendar::daysInYear**
        ().
        """
        ...

    @typing.overload
    def dayOfYear(self, cal: QCalendar) -> int:
        """
        https://doc.qt.io/qt-6/qdate.html#dayOfYear-1

        **int QDate::dayOfYear() const**

        This is an overloaded function.
        """
        ...

    @typing.overload
    def dayOfWeek(self) -> int:
        """
        https://doc.qt.io/qt-6/qdate.html#dayOfWeek

        **int QDate::dayOfWeek(QCalendar cal ) const**

        Returns the weekday (1 = Monday to 7 = Sunday) for this date.

        Uses **cal** as calendar if supplied, else the Gregorian calendar.
        Returns 0 if the date is invalid. Some calendars may give special
        meaning (e.g. intercallary days) to values greater than 7.

        **See also** **day** (), **dayOfYear** (), **QCalendar::dayOfWeek** (),
        and **Qt::DayOfWeek** .
        """
        ...

    @typing.overload
    def dayOfWeek(self, cal: QCalendar) -> int:
        """
        https://doc.qt.io/qt-6/qdate.html#dayOfWeek-1

        **int QDate::dayOfWeek() const**

        This is an overloaded function.
        """
        ...

    @typing.overload
    def day(self) -> int:
        """
        https://doc.qt.io/qt-6/qdate.html#day

        **int QDate::day(QCalendar cal ) const**

        Returns the day of the month for this date.

        Uses **cal** as calendar if supplied, else the Gregorian calendar (for
        which the return ranges from 1 to 31). Returns 0 if the date is invalid.

        **See also** **year** (), **month** (), **dayOfWeek** (), and
        **QCalendar::partsFromDate** ().
        """
        ...

    @typing.overload
    def day(self, cal: QCalendar) -> int:
        """
        https://doc.qt.io/qt-6/qdate.html#day-1

        **int QDate::day() const**

        This is an overloaded function.
        """
        ...

    @typing.overload
    def month(self) -> int:
        """
        https://doc.qt.io/qt-6/qdate.html#month

        **int QDate::month(QCalendar cal ) const**

        Returns the month-number for the date.

        Numbers the months of the year starting with 1 for the first. Uses
        **cal** as calendar if supplied, else the Gregorian calendar, for which
        the month numbering is as follows:

        * 1 = "January"
          * 2 = "February"
          * 3 = "March"
          * 4 = "April"
          * 5
        = "May"
          * 6 = "June"
          * 7 = "July"
          * 8 = "August"
          * 9 =
        "September"
          * 10 = "October"
          * 11 = "November"
          * 12 = "December"

        Returns 0 if the date is invalid. Note that some calendars may have more
        than 12 months in some years.

        **See also** **year** (), **day** (), and **QCalendar::partsFromDate**
        ().
        """
        ...

    @typing.overload
    def month(self, cal: QCalendar) -> int:
        """
        https://doc.qt.io/qt-6/qdate.html#month-1

        **int QDate::month() const**

        This is an overloaded function.
        """
        ...

    @typing.overload
    def year(self) -> int:
        """
        https://doc.qt.io/qt-6/qdate.html#year

        **int QDate::year(QCalendar cal ) const**

        Returns the year of this date.

        Uses **cal** as calendar, if supplied, else the Gregorian calendar.

        Returns 0 if the date is invalid. For some calendars, dates before their
        first year may all be invalid.

        If using a calendar which has a year 0, check using **isValid** () if
        the return is 0. Such calendars use negative year numbers in the obvious
        way, with year 1 preceded by year 0, in turn preceded by year -1 and so
        on.

        Some calendars, despite having no year 0, have a conventional numbering
        of the years before their first year, counting backwards from 1. For
        example, in the proleptic Gregorian calendar, successive years before 1
        CE (the first year) are identified as 1 BCE, 2 BCE, 3 BCE and so on. For
        such calendars, negative year numbers are used to indicate these years
        before year 1, with -1 indicating the year before 1.

        **See also** **month** (), **day** (), **QCalendar::hasYearZero** (),
        **QCalendar::isProleptic** (), and **QCalendar::partsFromDate** ().
        """
        ...

    @typing.overload
    def year(self, cal: QCalendar) -> int:
        """
        https://doc.qt.io/qt-6/qdate.html#year-1

        **int QDate::year() const**

        This is an overloaded function.
        """
        ...

    @typing.overload
    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdate.html#isValid

        **bool QDate::isValid() const**

        Returns `true` if this date is valid; otherwise returns `false`.

        **See also** **isNull** () and **QCalendar::isDateValid** ().
        """
        ...

    @typing.overload
    @staticmethod
    def isValid(y: int, m: int, d: int) -> bool:
        """
        https://doc.qt.io/qt-6/qdate.html#isValid-1

        **[static] bool QDate::isValid(int year , int month , int day )**

        This is an overloaded function.

        Returns `true` if the specified date ( **year** , **month** , and
        **day** ) is valid in the Gregorian calendar; otherwise returns `false`.

        Example:

        QDate::isValid(2002, 5, 17);  // true
            QDate::isValid(2002, 2, 30);
        // false (Feb 30 does not exist)
            QDate::isValid(2004, 2, 29);  //
        true (2004 is a leap year)
            QDate::isValid(2000, 2, 29);  // true
        (2000 is a leap year)
            QDate::isValid(2006, 2, 29);  // false (2006
        is not a leap year)
            QDate::isValid(2100, 2, 29);  // false (2100 is
        not a leap year)
            QDate::isValid(1202, 6, 6);   // true (even though
        1202 is pre-Gregorian)

        **See also** **isNull** (), **setDate** (), and
        **QCalendar::isDateValid** ().
        """
        ...

    def __bool__(self) -> int:
        ...

    def isNull(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdate.html#isNull

        **bool QDate::isNull() const**

        Returns `true` if the date is null; otherwise returns `false`. A null
        date is invalid.

        **Note:** The behavior of this function is equivalent to **isValid** ().

        **See also** **isValid** ().
        """
        ...

    def toPyDate(self) -> datetime.date:
        ...

    def __hash__(self) -> int:
        ...

    def __repr__(self) -> str:
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtCore import *


class QAbstractEventDispatcher(QObject):
    """
    https://doc.qt.io/qt-6/qabstracteventdispatcher.html

    **Detailed Description**

    An event dispatcher receives events from the window system and other
    sources. It then sends them to the **QCoreApplication**  or **QApplication**
    instance for processing and delivery. QAbstractEventDispatcher provides
    fine-grained control over event delivery.

    For simple control of event processing use
    **QCoreApplication::processEvents** ().

    For finer control of the application's event loop, call **instance** () and
    call functions on the QAbstractEventDispatcher object that is returned. If
    you want to use your own instance of QAbstractEventDispatcher or of a
    QAbstractEventDispatcher subclass, you must install it with
    **QCoreApplication::setEventDispatcher** () or
    **QThread::setEventDispatcher** () **before** a default event dispatcher has
    been installed.

    The main event loop is started by calling **QCoreApplication::exec** (), and
    stopped by calling **QCoreApplication::exit** (). Local event loops can be
    created using **QEventLoop** .

    Programs that perform long operations can call **processEvents** () with a
    bitwise OR combination of various **QEventLoop::ProcessEventsFlag**  values
    to control which events should be delivered.

    QAbstractEventDispatcher also allows the integration of an external event
    loop with the Qt event loop.

    **See also** **QEventLoop** , **QCoreApplication** , and **QThread** .
    """

    class TimerInfo(PyQt6.sip.simplewrapper):
        interval: int = ...
        timerId: int = ...
        timerType: Qt = ...

        @typing.overload
        def __init__(self, id: int, i: int, t: Qt.TimerType) -> None:
            ...

        @typing.overload
        def __init__(self, a0: "QAbstractEventDispatcher.TimerInfo") -> None:
            ...

    def __init__(self, parent: typing.Optional[QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qabstracteventdispatcher.html#QAbstractEventDispa
        tcher

        **QAbstractEventDispatcher::QAbstractEventDispatcher(QObject * parent =
        nullptr)**

        Constructs a new event dispatcher with the given **parent**.
        """
        ...

    def filterNativeEvent(
        self, eventType: "QByteArray", message: PyQt6.sip.voidptr
    ) -> typing.Tuple[bool, PyQt6.sip.voidptr]:
        """
        https://doc.qt.io/qt-6/qabstracteventdispatcher.html#filterNativeEvent

        **[since 5.0] bool QAbstractEventDispatcher::filterNativeEvent(const
        QByteArray & eventType , void * message , qintptr * result )**

        Sends **message** through the event filters that were set by
        **installNativeEventFilter** (). This function returns `true` as soon as
        an event filter returns `true`, and false otherwise to indicate that the
        processing of the event should continue.

        Subclasses of **QAbstractEventDispatcher**  **must** call this function
        for **all** messages received from the system to ensure compatibility
        with any extensions that may be used in the application. The type of
        event **eventType** is specific to the platform plugin chosen at run-
        time, and can be used to cast message to the right type. The **result**
        pointer is only used on Windows, and corresponds to the LRESULT pointer.

        Note that the type of **message** is platform dependent. See
        **QAbstractNativeEventFilter**  for details.

        This function was introduced in Qt 5.0.

        **See also** **installNativeEventFilter** () and
        **QAbstractNativeEventFilter::nativeEventFilter** ().
        """
        ...

    def removeNativeEventFilter(self, filterObj: "QAbstractNativeEventFilter") -> None:
        """
        https://doc.qt.io/qt-6/qabstracteventdispatcher.html#removeNativeEventFi
        lter

        **[since 5.0] void QAbstractEventDispatcher::removeNativeEventFilter(QAb
        stractNativeEventFilter * filter )**

        Removes the event filter **filter** from this object. The request is
        ignored if such an event filter has not been installed.

        All event filters for this object are automatically removed when this
        object is destroyed.

        It is always safe to remove an event filter, even during event filter
        filter activation (that is, even from within the **nativeEventFilter**
        () function).

        This function was introduced in Qt 5.0.

        **See also** **installNativeEventFilter** () and
        **QAbstractNativeEventFilter** .
        """
        ...

    def installNativeEventFilter(self, filterObj: "QAbstractNativeEventFilter") -> None:
        """
        https://doc.qt.io/qt-6/qabstracteventdispatcher.html#installNativeEventF
        ilter

        **[since 5.0] void QAbstractEventDispatcher::installNativeEventFilter(QA
        bstractNativeEventFilter * filterObj )**

        Installs an event filter **filterObj** for all native events received by
        the application.

        The event filter **filterObj** receives events via its
        **nativeEventFilter** () function, which is called for all events
        received by all threads.

        The **nativeEventFilter** () function should return true if the event
        should be filtered, (in this case, stopped). It should return false to
        allow normal Qt processing to continue: the native event can then be
        translated into a **QEvent**  and handled by the standard Qt **event**
        filtering, e.g. **QObject::installEventFilter** ().

        If multiple event filters are installed, the filter that was installed
        last is activated first.

        **Note:** The filter function set here receives native messages, that
        is, MSG or XEvent structs.

        For maximum portability, you should always try to use **QEvent**
        objects and **QObject::installEventFilter** () whenever possible.

        This function was introduced in Qt 5.0.

        **See also** **QObject::installEventFilter** ().
        """
        ...

    def remainingTime(self, timerId: int) -> int:
        """
        https://doc.qt.io/qt-6/qabstracteventdispatcher.html#remainingTime

        **[pure virtual] int QAbstractEventDispatcher::remainingTime(int timerId
        )**

        Returns the remaining time in milliseconds with the given **timerId**.
        If the timer is inactive, the returned value will be -1. If the timer is
        overdue, the returned value will be 0.

        **See also** **Qt::TimerType** .
        """
        ...

    def closingDown(self) -> None:
        ...

    def startingUp(self) -> None:
        ...

    def interrupt(self) -> None:
        """
        https://doc.qt.io/qt-6/qabstracteventdispatcher.html#interrupt

        **[pure virtual] void QAbstractEventDispatcher::interrupt()**

        Interrupts event dispatching. The event dispatcher will return from
        **processEvents** () as soon as possible.
        """
        ...

    def wakeUp(self) -> None:
        """
        https://doc.qt.io/qt-6/qabstracteventdispatcher.html#wakeUp

        **[pure virtual] void QAbstractEventDispatcher::wakeUp()**

        Wakes up the event loop.

        **Note:** This function is **thread-safe** .

        **See also** **awake** ().
        """
        ...

    def registeredTimers(
        self, object: QObject
    ) -> typing.List["QAbstractEventDispatcher.TimerInfo"]:
        """
        https://doc.qt.io/qt-6/qabstracteventdispatcher.html#registeredTimers

        **[pure virtual] QList<QAbstractEventDispatcher::TimerInfo>
        QAbstractEventDispatcher::registeredTimers(QObject * object ) const**

        Returns a list of registered timers for **object**. The **TimerInfo**
        struct has `timerId`, `interval`, and `timerType` members.

        **See also** **Qt::TimerType** .
        """
        ...

    def unregisterTimers(self, object: QObject) -> bool:
        """
        https://doc.qt.io/qt-6/qabstracteventdispatcher.html#unregisterTimers

        **[pure virtual] bool QAbstractEventDispatcher::unregisterTimers(QObject
        * object )**

        Unregisters all the timers associated with the given **object**. Returns
        `true` if all timers were successful removed; otherwise returns `false`.

        **See also** **unregisterTimer** () and **registeredTimers** ().
        """
        ...

    def unregisterTimer(self, timerId: int) -> bool:
        """
        https://doc.qt.io/qt-6/qabstracteventdispatcher.html#unregisterTimer

        **[pure virtual] bool QAbstractEventDispatcher::unregisterTimer(int
        timerId )**

        Unregisters the timer with the given **timerId**. Returns `true` if
        successful; otherwise returns `false`.

        **See also** **registerTimer** () and **unregisterTimers** ().
        """
        ...

    @typing.overload
    def registerTimer(
        self, interval: int, timerType: Qt.TimerType, object: QObject
    ) -> int:
        """
        https://doc.qt.io/qt-6/qabstracteventdispatcher.html#registerTimer

        **int QAbstractEventDispatcher::registerTimer(qint64 interval ,
        Qt::TimerType timerType , QObject * object )**

        Registers a timer with the specified **interval** and **timerType** for
        the given **object** and returns the timer id.
        """
        ...

    @typing.overload
    def registerTimer(
        self, timerId: int, interval: int, timerType: Qt.TimerType, object: QObject
    ) -> None:
        """
        https://doc.qt.io/qt-6/qabstracteventdispatcher.html#registerTimer-1

        **[pure virtual] void QAbstractEventDispatcher::registerTimer(int
        timerId , qint64 interval , Qt::TimerType timerType , QObject * object
        )**

        Register a timer with the specified **timerId** , **interval** , and
        **timerType** for the given **object**.
        """
        ...

    def processEvents(self, flags: "QEventLoop.ProcessEventsFlag") -> bool:
        """
        https://doc.qt.io/qt-6/qabstracteventdispatcher.html#processEvents

        **[pure virtual] bool
        QAbstractEventDispatcher::processEvents(QEventLoop::ProcessEventsFlags
        flags )**

        Processes pending events that match **flags** until there are no more
        events to process. Returns `true` if an event was processed; otherwise
        returns `false`.

        This function is especially useful if you have a long running operation,
        and want to show its progress without allowing user input by using the
        **QEventLoop::ExcludeUserInputEvents**  flag.

        If the **QEventLoop::WaitForMoreEvents**  flag is set in **flags** , the
        behavior of this function is as follows:

        * If events are available, this function returns after processing them.
        * If no events are available, this function will wait until more are
        available and return after processing newly available events.

        If the **QEventLoop::WaitForMoreEvents**  flag is not set in **flags** ,
        and no events are available, this function will return immediately.

        **Note:** This function does not process events continuously; it returns
        after all available events are processed.
        """
        ...

    @staticmethod
    def instance(
        thread: typing.Optional["QThread"] = ...,
    ) -> "QAbstractEventDispatcher":
        """
        https://doc.qt.io/qt-6/qabstracteventdispatcher.html#instance

        **[static] QAbstractEventDispatcher
        *QAbstractEventDispatcher::instance(QThread * thread = nullptr)**

        Returns a pointer to the event dispatcher object for the specified
        **thread**. If **thread** is `nullptr`, the current thread is used. If
        no event dispatcher exists for the specified thread, this function
        returns `nullptr`.

        **Note:** If Qt is built without thread support, the **thread** argument
        is ignored.
        """
        ...

    @property
    def aboutToBlock(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qabstracteventdispatcher.html#aboutToBlock

        **[signal] void QAbstractEventDispatcher::aboutToBlock()**

        This signal is emitted before the event loop calls a function that could
        block.

        **See also** **awake** ().
        """
        ...

    @property
    def awake(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qabstracteventdispatcher.html#awake

        **[signal] void QAbstractEventDispatcher::awake()**

        This signal is emitted after the event loop returns from a function that
        could block.

        **See also** **wakeUp** () and **aboutToBlock** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip


class QAxObjectInterface(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qaxobjectinterface.html

    **Detailed Description**
    """

    @typing.overload
    def __init__(self) -> None:
        ...

    @typing.overload
    def __init__(self, a0: "QAxObjectInterface") -> None:
        ...

    def resetControl(self) -> None:
        """
        https://doc.qt.io/qt-6/qaxobjectinterface.html#resetControl

        **[pure virtual] void QAxObjectInterface::resetControl()**

        Disconnects and destroys the COM object.

        **See also** **QAxBaseWidget::control**  and **QAxBaseObject::control**
        .
        """
        ...

    def setControl(self, c: str) -> bool:
        """
        https://doc.qt.io/qt-6/qaxobjectinterface.html#setControl

        **[pure virtual] bool QAxObjectInterface::setControl(const QString & c
        )**

        Returns whether setting the COM object succeeded.

        Sets the name of the COM object wrapped by this **QAxBase**  object to
        **c**.

        **See also** **QAxBaseWidget::control**  and **QAxBaseObject::control**
        .
        """
        ...

    def control(self) -> str:
        """
        https://doc.qt.io/qt-6/qaxobjectinterface.html#control

        **[pure virtual] QString QAxObjectInterface::control() const**

        Returns the name of the COM object wrapped by this **QAxBase**  object.

        **See also** **setControl** (), **QAxBaseWidget::control** , and
        **QAxBaseObject::control** .
        """
        ...

    def setClassContext(self, classContext: int) -> None:
        """
        https://doc.qt.io/qt-6/qaxobjectinterface.html#setClassContext

        **[pure virtual] void QAxObjectInterface::setClassContext(ulong
        classContext )**

        Sets the context the ActiveX control will run in to **classContext**

        Affects the "dwClsContext" argument when calling CoCreateInstance. This
        can be used to control in-proc vs. out-of-proc startup for controls
        supporting both alternatives. Also, it can be used to modify/reduce
        control permissions when used with CLSCTX_ENABLE_CLOAKING and an
        impersonation token.

        Note that this function must be called before **setControl** () to have
        any effect.

        **See also** **QAxBaseWidget::classContext**  and
        **QAxBaseObject::classContext** .
        """
        ...

    def classContext(self) -> int:
        """
        https://doc.qt.io/qt-6/qaxobjectinterface.html#classContext

        **[pure virtual] ulong QAxObjectInterface::classContext() const**

        Returns the context the ActiveX control will run in (default
        CLSCTX_SERVER).

        **See also** **setClassContext** (), **QAxBaseWidget::classContext** ,
        and **QAxBaseObject::classContext** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtQml import *
import enum


class QQmlIncubator(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qqmlincubator.html

    **Detailed Description**

    Creating QML objects - like delegates in a view, or a new page in an
    application - can take a noticeable amount of time, especially on resource
    constrained mobile devices. When an application uses
    **QQmlComponent::create** () directly, the QML object instance is created
    synchronously which, depending on the complexity of the object, can cause
    noticeable pauses or stutters in the application.

    The use of QQmlIncubator gives more control over the creation of a QML
    object, including allowing it to be created asynchronously using application
    idle time. The following example shows a simple use of QQmlIncubator.

    QQmlIncubator incubator;
        component->create(incubator);

        while
    (!incubator.isReady()) {
            **QCoreApplication**
    ::processEvents(**QEventLoop** ::AllEvents, 50);
        }

        **QObject**
    *object = incubator.object();

    Asynchronous incubators are controlled by a **QQmlIncubationController**
    that is set on the **QQmlEngine** , which lets the engine know when the
    application is idle and incubating objects should be processed. If an
    incubation controller is not set on the **QQmlEngine** , QQmlIncubator
    creates objects synchronously regardless of the specified **IncubationMode**
    .

    QQmlIncubator supports three incubation modes:

    * Synchronous The creation occurs synchronously. That is, once the
    **QQmlComponent::create** () call returns, the incubator will already be in
    either the Error or Ready state. A synchronous incubator has no real
    advantage compared to using the synchronous creation methods on
    **QQmlComponent**  directly, but it may simplify an application's
    implementation to use the same API for both synchronous and asynchronous
    creations.
      * Asynchronous (default) The creation occurs asynchronously,
    assuming a QQmlIncubatorController is set on the **QQmlEngine** .

    The
    incubator will remain in the Loading state until either the creation is
    complete or an error occurs. The **statusChanged** () callback can be used
    to be notified of status changes.

    Applications should use the Asynchronous
    incubation mode to create objects that are not needed immediately. For
    example, the **ListView**  type uses Asynchronous incubation to create
    objects that are slightly off screen while the list is being scrolled. If,
    during asynchronous creation, the object is needed immediately the
    **QQmlIncubator::forceCompletion** () method can be called to complete the
    creation process synchronously.

      * **AsynchronousIfNested**  The creation
    will occur asynchronously if part of a nested asynchronous creation, or
    synchronously if not.

    In most scenarios where a QML component wants the
    appearance of a synchronous instantiation, it should use this mode.

    This
    mode is best explained with an example. When the **ListView**  type is first
    created, it needs to populate itself with an initial set of delegates to
    show. If the **ListView**  was 400 pixels high, and each delegate was 100
    pixels high, it would need to create four initial delegate instances. If the
    **ListView**  used the Asynchronous incubation mode, the **ListView**  would
    always be created empty and then, sometime later, the four initial items
    would appear.

    Conversely, if the **ListView**  was to use the Synchronous
    incubation mode it would behave correctly but it may introduce stutters into
    the application. As QML would have to stop and instantiate the **ListView**
    's delegates synchronously, if the **ListView**  was part of a QML component
    that was being instantiated asynchronously this would undo much of the
    benefit of asynchronous instantiation.

    The **AsynchronousIfNested**  mode
    reconciles this problem. By using **AsynchronousIfNested** , the
    **ListView**  delegates are instantiated asynchronously if the **ListView**
    itself is already part of an asynchronous instantiation, and synchronously
    otherwise. In the case of a nested asynchronous instantiation, the outer
    asynchronous instantiation will not complete until after all the nested
    instantiations have also completed. This ensures that by the time the outer
    asynchronous instantitation completes, inner items like **ListView**  have
    already completed loading their initial delegates.

    It is almost always
    incorrect to use the Synchronous incubation mode - elements or components
    that want the appearance of synchronous instantiation, but without the
    downsides of introducing freezes or stutters into the application, should
    use the **AsynchronousIfNested**  incubation mode.
    """

    class Status(enum.Enum):
        Null: QQmlIncubator = ...
        Ready: QQmlIncubator = ...
        Loading: QQmlIncubator = ...
        Error: QQmlIncubator = ...

    class IncubationMode(enum.Enum):
        Asynchronous: QQmlIncubator = ...
        AsynchronousIfNested: QQmlIncubator = ...
        Synchronous: QQmlIncubator = ...

    def __init__(self, mode: "QQmlIncubator.IncubationMode" = ...) -> None:
        """
        https://doc.qt.io/qt-6/qqmlincubator.html#QQmlIncubator-1

        **QQmlIncubator::QQmlIncubator(QQmlIncubator::IncubationMode mode =
        Asynchronous)**

        Create a new incubator with the specified **mode**
        """
        ...

    def setInitialState(self, a0: QtCore.QObject) -> None:
        """
        https://doc.qt.io/qt-6/qqmlincubator.html#setInitialState

        **[virtual protected] void QQmlIncubator::setInitialState(QObject *
        object )**

        Called after the **object** is first created, but before property
        bindings are evaluated and, if applicable,
        **QQmlParserStatus::componentComplete** () is called. This is equivalent
        to the point between **QQmlComponent::beginCreate** () and
        **QQmlComponent::completeCreate** (), and can be used to assign initial
        values to the object's properties.

        The default implementation does nothing.
        """
        ...

    def statusChanged(self, a0: "QQmlIncubator.Status") -> None:
        """
        https://doc.qt.io/qt-6/qqmlincubator.html#statusChanged

        **[virtual protected] void
        QQmlIncubator::statusChanged(QQmlIncubator::Status status )**

        Called when the status of the incubator changes. **status** is the new
        status.

        The default implementation does nothing.
        """
        ...

    def setInitialProperties(
        self, initialProperties: typing.Dict[str, typing.Any]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qqmlincubator.html#setInitialProperties

        **[since 5.15] void QQmlIncubator::setInitialProperties(const
        QVariantMap & initialProperties )**

        Stores a mapping from property names to initial values, contained in
        **initialProperties** , with which the incubated component will be
        initialized.

        This function was introduced in Qt 5.15.

        **See also** **QQmlComponent::setInitialProperties** .
        """
        ...

    def object(self) -> QtCore.QObject:
        """
        https://doc.qt.io/qt-6/qqmlincubator.html#object

        **QObject *QQmlIncubator::object() const**

        Return the incubated object if the status is Ready, otherwise 0.
        """
        ...

    def status(self) -> "QQmlIncubator.Status":
        """
        https://doc.qt.io/qt-6/qqmlincubator.html#status

        **QQmlIncubator::Status QQmlIncubator::status() const**

        Return the current status of the incubator.
        """
        ...

    def incubationMode(self) -> "QQmlIncubator.IncubationMode":
        """
        https://doc.qt.io/qt-6/qqmlincubator.html#incubationMode

        **QQmlIncubator::IncubationMode QQmlIncubator::incubationMode() const**

        Return the incubation mode passed to the **QQmlIncubator**  constructor.
        """
        ...

    def errors(self) -> typing.List[QQmlError]:
        """
        https://doc.qt.io/qt-6/qqmlincubator.html#errors

        **QList<QQmlError> QQmlIncubator::errors() const**

        Return the list of errors encountered while incubating the object.
        """
        ...

    def isLoading(self) -> bool:
        """
        https://doc.qt.io/qt-6/qqmlincubator.html#isLoading

        **bool QQmlIncubator::isLoading() const**

        Returns true if the incubator's **status** () is Loading.
        """
        ...

    def isError(self) -> bool:
        """
        https://doc.qt.io/qt-6/qqmlincubator.html#isError

        **bool QQmlIncubator::isError() const**

        Returns true if the incubator's **status** () is Error.
        """
        ...

    def isReady(self) -> bool:
        """
        https://doc.qt.io/qt-6/qqmlincubator.html#isReady

        **bool QQmlIncubator::isReady() const**

        Returns true if the incubator's **status** () is Ready.
        """
        ...

    def isNull(self) -> bool:
        """
        https://doc.qt.io/qt-6/qqmlincubator.html#isNull

        **bool QQmlIncubator::isNull() const**

        Returns true if the incubator's **status** () is Null.
        """
        ...

    def forceCompletion(self) -> None:
        """
        https://doc.qt.io/qt-6/qqmlincubator.html#forceCompletion

        **void QQmlIncubator::forceCompletion()**

        Force any in-progress incubation to finish synchronously. Once this call
        returns, the incubator will not be in the Loading state.
        """
        ...

    def clear(self) -> None:
        """
        https://doc.qt.io/qt-6/qqmlincubator.html#clear

        **void QQmlIncubator::clear()**

        Clears the incubator. Any in-progress incubation is aborted. If the
        incubator is in the Ready state, the created object is **not** deleted.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QPdfWriter(QtCore.QObject, QPagedPaintDevice):
    """
    https://doc.qt.io/qt-6/qpdfwriter.html

    **Detailed Description**

    QPdfWriter generates PDF out of a series of drawing commands using
    **QPainter** . The **newPage** () method can be used to create several
    pages.
    """

    @typing.overload
    def __init__(self, filename: str) -> None:
        """
        https://doc.qt.io/qt-6/qpdfwriter.html#QPdfWriter

        **QPdfWriter::QPdfWriter(const QString & filename )**

        Constructs a PDF writer that will write the pdf to **filename**.
        """
        ...

    @typing.overload
    def __init__(self, device: QtCore.QIODevice) -> None:
        """
        https://doc.qt.io/qt-6/qpdfwriter.html#QPdfWriter-1

        **QPdfWriter::QPdfWriter(QIODevice * device )**

        Constructs a PDF writer that will write the pdf to **device**.
        """
        ...

    def addFileAttachment(
        self, fileName: str, data: QtCore.QByteArray, mimeType: str = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qpdfwriter.html#addFileAttachment

        **[since 5.15] void QPdfWriter::addFileAttachment(const QString &
        fileName , const QByteArray & data , const QString & mimeType =
        QString())**

        Adds **fileName** attachment to the PDF with (optional) **mimeType**.
        **data** contains the raw file data to embed into the PDF file.

        This function was introduced in Qt 5.15.
        """
        ...

    def documentXmpMetadata(self) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qpdfwriter.html#documentXmpMetadata

        **[since 5.15] QByteArray QPdfWriter::documentXmpMetadata() const**

        Gets the document metadata, as it was provided with a call to
        **setDocumentXmpMetadata** . It will not return the default metadata.

        This function was introduced in Qt 5.15.

        **See also** **setDocumentXmpMetadata** ().
        """
        ...

    def setDocumentXmpMetadata(self, xmpMetadata: QtCore.QByteArray) -> None:
        """
        https://doc.qt.io/qt-6/qpdfwriter.html#setDocumentXmpMetadata

        **[since 5.15] void QPdfWriter::setDocumentXmpMetadata(const QByteArray
        & xmpMetadata )**

        Sets the document metadata. This metadata is not influenced by the
        **setTitle**  / **setCreator**  methods, so is up to the user to keep it
        consistent. **xmpMetadata** contains XML formatted metadata to embed
        into the PDF file.

        This function was introduced in Qt 5.15.

        **See also** **documentXmpMetadata** ().
        """
        ...

    def pdfVersion(self) -> QPagedPaintDevice.PdfVersion:
        """
        https://doc.qt.io/qt-6/qpdfwriter.html#pdfVersion

        **[since 5.10] QPagedPaintDevice::PdfVersion QPdfWriter::pdfVersion()
        const**

        Returns the PDF version for this writer. The default is
        `PdfVersion_1_4`.

        This function was introduced in Qt 5.10.

        **See also** **setPdfVersion** ().
        """
        ...

    def setPdfVersion(self, version: QPagedPaintDevice.PdfVersion) -> None:
        """
        https://doc.qt.io/qt-6/qpdfwriter.html#setPdfVersion

        **[since 5.10] void
        QPdfWriter::setPdfVersion(QPagedPaintDevice::PdfVersion version )**

        Sets the PDF version for this writer to **version**.

        If **version** is the same value as currently set then no change will be
        made.

        This function was introduced in Qt 5.10.

        **See also** **pdfVersion** ().
        """
        ...

    def resolution(self) -> int:
        """
        https://doc.qt.io/qt-6/qpdfwriter.html#resolution

        **[since 5.3] int QPdfWriter::resolution() const**

        Returns the resolution of the PDF in DPI.

        This function was introduced in Qt 5.3.

        **See also** **setResolution** ().
        """
        ...

    def setResolution(self, resolution: int) -> None:
        """
        https://doc.qt.io/qt-6/qpdfwriter.html#setResolution

        **[since 5.3] void QPdfWriter::setResolution(int resolution )**

        Sets the PDF **resolution** in DPI.

        This setting affects the coordinate system as returned by, for example
        **QPainter::viewport** ().

        This function was introduced in Qt 5.3.

        **See also** **resolution** ().
        """
        ...

    def metric(self, id: QPaintDevice.PaintDeviceMetric) -> int:
        ...

    def paintEngine(self) -> QPaintEngine:
        """
        https://doc.qt.io/qt-6/qpdfwriter.html#paintEngine

        **[override virtual protected] QPaintEngine *QPdfWriter::paintEngine()
        const**

        Reimplements: **QPaintDevice::paintEngine() const** .
        """
        ...

    def newPage(self) -> bool:
        """
        https://doc.qt.io/qt-6/qpdfwriter.html#newPage

        **[override virtual] bool QPdfWriter::newPage()**

        Reimplements: **QPagedPaintDevice::newPage** ().
        """
        ...

    def setCreator(self, creator: str) -> None:
        """
        https://doc.qt.io/qt-6/qpdfwriter.html#setCreator

        **void QPdfWriter::setCreator(const QString & creator )**

        Sets the creator of the document to **creator**.

        **See also** **creator** ().
        """
        ...

    def creator(self) -> str:
        """
        https://doc.qt.io/qt-6/qpdfwriter.html#creator

        **QString QPdfWriter::creator() const**

        Returns the creator of the document.

        **See also** **setCreator** ().
        """
        ...

    def setTitle(self, title: str) -> None:
        """
        https://doc.qt.io/qt-6/qpdfwriter.html#setTitle

        **void QPdfWriter::setTitle(const QString & title )**

        Sets the title of the document being created to **title**.

        **See also** **title** ().
        """
        ...

    def title(self) -> str:
        """
        https://doc.qt.io/qt-6/qpdfwriter.html#title

        **QString QPdfWriter::title() const**

        Returns the title of the document.

        **See also** **setTitle** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *
import enum


class QProgressBar(QWidget):
    """
    https://doc.qt.io/qt-6/qprogressbar.html

    **Detailed Description**

    ![](images/windows-progressbar.png)

    A progress bar is used to give the user an indication of the progress of an
    operation and to reassure them that the application is still running.

    The progress bar uses the concept of **steps**. You set it up by specifying
    the minimum and maximum possible step values, and it will display the
    percentage of steps that have been completed when you later give it the
    current step value. The percentage is calculated by dividing the progress
    (**value** () - **minimum** ()) divided by **maximum** () - **minimum** ().

    You can specify the minimum and maximum number of steps with **setMinimum**
    () and **setMaximum** . The current number of steps is set with **setValue**
    (). The progress bar can be rewound to the beginning with **reset** ().

    If minimum and maximum both are set to 0, the bar shows a busy indicator
    instead of a percentage of steps. This is useful, for example, when using
    QNetworkAccessManager to download items when they are unable to determine
    the size of the item being downloaded.

    **See also** **QProgressDialog**  and **GUI Design Handbook: Progress
    Indicator** .
    """

    class Direction(enum.Enum):
        TopToBottom: QProgressBar = ...
        BottomToTop: QProgressBar = ...

    def __init__(self, parent: typing.Optional[QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qprogressbar.html#QProgressBar

        **QProgressBar::QProgressBar(QWidget * parent = nullptr)**

        Constructs a progress bar with the given **parent**.

        By default, the minimum step value is set to 0, and the maximum to 100.

        **See also** **setRange** ().
        """
        ...

    def paintEvent(self, a0: QtGui.QPaintEvent) -> None:
        """
        https://doc.qt.io/qt-6/qprogressbar.html#paintEvent

        **[override virtual protected] void QProgressBar::paintEvent(QPaintEvent
        *)**

        Reimplements: **QWidget::paintEvent** (QPaintEvent *event).
        """
        ...

    def event(self, e: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qprogressbar.html#event

        **[override virtual protected] bool QProgressBar::event(QEvent * e )**

        Reimplements: **QWidget::event** (QEvent *event).
        """
        ...

    def initStyleOption(self, option: "QStyleOptionProgressBar") -> None:
        """
        https://doc.qt.io/qt-6/qprogressbar.html#initStyleOption

        **[virtual protected] void
        QProgressBar::initStyleOption(QStyleOptionProgressBar * option ) const**

        Initialize **option** with the values from this **QProgressBar** . This
        method is useful for subclasses when they need a
        **QStyleOptionProgressBar** , but don't want to fill in all the
        information themselves.

        **See also** **QStyleOption::initFrom** ().
        """
        ...

    def setOrientation(self, a0: QtCore.Qt.Orientation) -> None:
        """
        https://doc.qt.io/qt-6/qprogressbar.html#orientation-prop

        **orientation : Qt::Orientation**

        This property holds the orientation of the progress bar

        The orientation must be **Qt::Horizontal**  (the default) or
        **Qt::Vertical** .

        **Access functions:**

        Qt::Orientation **orientation** () const
        void **setOrientation**
        (Qt::Orientation)

        **See also** **invertedAppearance**  and **textDirection** .
        """
        ...

    def setValue(self, value: int) -> None:
        """
        https://doc.qt.io/qt-6/qprogressbar.html#value-prop

        **value : int**

        This property holds the progress bar's current value

        Attempting to change the current value to one outside the minimum-
        maximum range has no effect on the current value.

        **Access functions:**

        int **value** () const
        void **setValue** (int **value** )

        **Notifier signal:**

        void ****valueChanged** ** (int **value** )

        **Member Function Documentation**
        """
        ...

    def setMaximum(self, maximum: int) -> None:
        """
        https://doc.qt.io/qt-6/qprogressbar.html#maximum-prop

        **maximum : int**

        This property holds the progress bar's maximum value

        When setting this property, the **minimum**  is adjusted if necessary to
        ensure that the range remains valid. If the current value falls outside
        the new range, the progress bar is reset with **reset** ().

        **Access functions:**

        int **maximum** () const
        void **setMaximum** (int **maximum** )
        """
        ...

    def setMinimum(self, minimum: int) -> None:
        """
        https://doc.qt.io/qt-6/qprogressbar.html#minimum-prop

        **minimum : int**

        This property holds the progress bar's minimum value

        When setting this property, the **maximum**  is adjusted if necessary to
        ensure that the range remains valid. If the current value falls outside
        the new range, the progress bar is reset with **reset** ().

        **Access functions:**

        int **minimum** () const
        void **setMinimum** (int **minimum** )
        """
        ...

    def reset(self) -> None:
        """
        https://doc.qt.io/qt-6/qprogressbar.html#reset

        **[slot] void QProgressBar::reset()**

        Reset the progress bar. The progress bar "rewinds" and shows no
        progress.
        """
        ...

    def resetFormat(self) -> None:
        ...

    def format(self) -> str:
        """
        https://doc.qt.io/qt-6/qprogressbar.html#format-prop

        **format : QString**

        This property holds the string used to generate the current text

        %p - is replaced by the percentage completed. %v - is replaced by the
        current value. %m - is replaced by the total number of steps.

        The default value is "%p%".

        **Access functions:**

        QString **format** () const
        void **setFormat** (const QString &
        **format** )
        void **resetFormat** ()

        **See also** **text** ().
        """
        ...

    def setFormat(self, format: str) -> None:
        """
        https://doc.qt.io/qt-6/qprogressbar.html#format-prop

        **format : QString**

        This property holds the string used to generate the current text

        %p - is replaced by the percentage completed. %v - is replaced by the
        current value. %m - is replaced by the total number of steps.

        The default value is "%p%".

        **Access functions:**

        QString **format** () const
        void **setFormat** (const QString &
        **format** )
        void **resetFormat** ()

        **See also** **text** ().
        """
        ...

    def setTextDirection(self, textDirection: "QProgressBar.Direction") -> None:
        """
        https://doc.qt.io/qt-6/qprogressbar.html#textDirection-prop

        **textDirection : Direction**

        This property holds the reading direction of the **text**  for vertical
        progress bars

        This property has no impact on horizontal progress bars. By default, the
        reading direction is **QProgressBar::TopToBottom** .

        **Access functions:**

        QProgressBar::Direction **textDirection** () const
        void
        **setTextDirection** (QProgressBar::Direction **textDirection** )

        **See also** **orientation**  and **textVisible** .
        """
        ...

    def setInvertedAppearance(self, invert: bool) -> None:
        """
        https://doc.qt.io/qt-6/qprogressbar.html#invertedAppearance-prop

        **invertedAppearance : bool**

        This property holds whether or not a progress bar shows its progress
        inverted

        If this property is `true`, the progress bar grows in the other
        direction (e.g. from right to left). By default, the progress bar is not
        inverted.

        **Access functions:**

        bool **invertedAppearance** () const
        void **setInvertedAppearance**
        (bool **invert** )

        **See also** **orientation**  and **layoutDirection** .
        """
        ...

    def orientation(self) -> QtCore.Qt.Orientation:
        """
        https://doc.qt.io/qt-6/qprogressbar.html#orientation-prop

        **orientation : Qt::Orientation**

        This property holds the orientation of the progress bar

        The orientation must be **Qt::Horizontal**  (the default) or
        **Qt::Vertical** .

        **Access functions:**

        Qt::Orientation **orientation** () const
        void **setOrientation**
        (Qt::Orientation)

        **See also** **invertedAppearance**  and **textDirection** .
        """
        ...

    def minimumSizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qprogressbar.html#minimumSizeHint

        **[override virtual] QSize QProgressBar::minimumSizeHint() const**

        Reimplements an access function for property:
        **QWidget::minimumSizeHint** .
        """
        ...

    def sizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qprogressbar.html#sizeHint

        **[override virtual] QSize QProgressBar::sizeHint() const**

        Reimplements an access function for property: **QWidget::sizeHint** .
        """
        ...

    def setAlignment(self, alignment: QtCore.Qt.AlignmentFlag) -> None:
        """
        https://doc.qt.io/qt-6/qprogressbar.html#alignment-prop

        **alignment : Qt::Alignment**

        This property holds the alignment of the progress bar

        **Access functions:**

        Qt::Alignment **alignment** () const
        void **setAlignment**
        (Qt::Alignment **alignment** )
        """
        ...

    def alignment(self) -> QtCore.Qt.AlignmentFlag:
        """
        https://doc.qt.io/qt-6/qprogressbar.html#alignment-prop

        **alignment : Qt::Alignment**

        This property holds the alignment of the progress bar

        **Access functions:**

        Qt::Alignment **alignment** () const
        void **setAlignment**
        (Qt::Alignment **alignment** )
        """
        ...

    def isTextVisible(self) -> bool:
        ...

    def setTextVisible(self, visible: bool) -> None:
        """
        https://doc.qt.io/qt-6/qprogressbar.html#textVisible-prop

        **textVisible : bool**

        This property holds whether the current completed percentage should be
        displayed

        This property may be ignored by the style (e.g., QMacStyle never draws
        the text).

        **Access functions:**

        bool **isTextVisible** () const
        void **setTextVisible** (bool
        **visible** )

        **See also** **textDirection** .
        """
        ...

    def text(self) -> str:
        """
        https://doc.qt.io/qt-6/qprogressbar.html#text-prop

        **[read-only] text : const QString**

        This property holds the descriptive text shown with the progress bar

        The text returned is the same as the text displayed in the center (or in
        some styles, to the left) of the progress bar.

        The progress shown in the text may be smaller than the minimum value,
        indicating that the progress bar is in the "reset" state before any
        progress is set.

        In the default implementation, the text either contains a percentage
        value that indicates the progress so far, or it is blank because the
        progress bar is in the reset state.

        **Access functions:**

        virtual QString **text** () const
        """
        ...

    def value(self) -> int:
        """
        https://doc.qt.io/qt-6/qprogressbar.html#value-prop

        **value : int**

        This property holds the progress bar's current value

        Attempting to change the current value to one outside the minimum-
        maximum range has no effect on the current value.

        **Access functions:**

        int **value** () const
        void **setValue** (int **value** )

        **Notifier signal:**

        void ****valueChanged** ** (int **value** )

        **Member Function Documentation**
        """
        ...

    def setRange(self, minimum: int, maximum: int) -> None:
        """
        https://doc.qt.io/qt-6/qprogressbar.html#setRange

        **[slot] void QProgressBar::setRange(int minimum , int maximum )**

        Sets the progress bar's minimum and maximum values to **minimum** and
        **maximum** respectively.

        If **maximum** is smaller than **minimum** , **minimum** becomes the
        only legal value.

        If the current value falls outside the new range, the progress bar is
        reset with **reset** ().

        The **QProgressBar**  can be set to undetermined state by using
        setRange(0, 0).

        **See also** **minimum**  and **maximum** .
        """
        ...

    def maximum(self) -> int:
        """
        https://doc.qt.io/qt-6/qprogressbar.html#maximum-prop

        **maximum : int**

        This property holds the progress bar's maximum value

        When setting this property, the **minimum**  is adjusted if necessary to
        ensure that the range remains valid. If the current value falls outside
        the new range, the progress bar is reset with **reset** ().

        **Access functions:**

        int **maximum** () const
        void **setMaximum** (int **maximum** )
        """
        ...

    def minimum(self) -> int:
        """
        https://doc.qt.io/qt-6/qprogressbar.html#minimum-prop

        **minimum : int**

        This property holds the progress bar's minimum value

        When setting this property, the **maximum**  is adjusted if necessary to
        ensure that the range remains valid. If the current value falls outside
        the new range, the progress bar is reset with **reset** ().

        **Access functions:**

        int **minimum** () const
        void **setMinimum** (int **minimum** )
        """
        ...

    @property
    def valueChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qprogressbar.html#valueChanged

        **[signal] void QProgressBar::valueChanged(int value )**

        This signal is emitted when the value shown in the progress bar changes.
        **value** is the new value shown by the progress bar.

        **Note:** Notifier signal for property **value** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtCore import *


class QByteArrayMatcher(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qbytearraymatcher.html

    **Detailed Description**

    This class is useful when you have a sequence of bytes that you want to
    repeatedly match against some byte arrays (perhaps in a loop), or when you
    want to search for the same sequence of bytes multiple times in the same
    byte array. Using a matcher object and **indexIn** () is faster than
    matching a plain **QByteArray**  with **QByteArray::indexOf** () if repeated
    matching takes place. This class offers no benefit if you are doing one-off
    byte array matches.

    Create the QByteArrayMatcher with the **QByteArray**  you want to search
    for. Then call **indexIn** () on the **QByteArray**  that you want to
    search.

    **See also** **QByteArray**  and **QStringMatcher** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qbytearraymatcher.html#QByteArrayMatcher

        **QByteArrayMatcher::QByteArrayMatcher()**

        Constructs an empty byte array matcher that won't match anything. Call
        **setPattern** () to give it a pattern to match.
        """
        ...

    @typing.overload
    def __init__(self, pattern: bytes, length: int) -> None:
        """
        https://doc.qt.io/qt-6/qbytearraymatcher.html#QByteArrayMatcher-1

        **QByteArrayMatcher::QByteArrayMatcher(const QByteArray & pattern )**

        Constructs a byte array matcher that will search for **pattern**. Call
        **indexIn** () to perform a search.
        """
        ...

    @typing.overload
    def __init__(self, pattern: QByteArray) -> None:
        """
        https://doc.qt.io/qt-6/qbytearraymatcher.html#QByteArrayMatcher-2

        **QByteArrayMatcher::QByteArrayMatcher(const char * pattern , qsizetype
        length )**

        Constructs a byte array matcher from **pattern**. **pattern** has the
        given **length**. Call **indexIn** () to perform a search.

        **Note:** the data that **pattern** is referencing must remain valid
        while this object is used.
        """
        ...

    @typing.overload
    def __init__(self, other: "QByteArrayMatcher") -> None:
        """
        https://doc.qt.io/qt-6/qbytearraymatcher.html#QByteArrayMatcher-3

        **QByteArrayMatcher::QByteArrayMatcher(const QByteArrayMatcher & other
        )**

        Copies the **other** byte array matcher to this byte array matcher.
        """
        ...

    def pattern(self) -> QByteArray:
        """
        https://doc.qt.io/qt-6/qbytearraymatcher.html#pattern

        **QByteArray QByteArrayMatcher::pattern() const**

        Returns the byte array pattern that this byte array matcher will search
        for.

        **See also** **setPattern** ().
        """
        ...

    @typing.overload
    def indexIn(self, str: bytes, len: int, from_: int = ...) -> int:
        """
        https://doc.qt.io/qt-6/qbytearraymatcher.html#indexIn

        **qsizetype QByteArrayMatcher::indexIn(const QByteArray & ba , qsizetype
        from = 0) const**

        Searches the byte array **ba** , from byte position **from** (default 0,
        i.e. from the first byte), for the byte array **pattern** () that was
        set in the constructor or in the most recent call to **setPattern** ().
        Returns the position where the **pattern** () matched in **ba** , or -1
        if no match was found.
        """
        ...

    @typing.overload
    def indexIn(self, ba: QByteArray, from_: int = ...) -> int:
        """
        https://doc.qt.io/qt-6/qbytearraymatcher.html#indexIn-1

        **qsizetype QByteArrayMatcher::indexIn(const char * str , qsizetype len
        , qsizetype from = 0) const**

        Searches the char string **str** , which has length **len** , from byte
        position **from** (default 0, i.e. from the first byte), for the byte
        array **pattern** () that was set in the constructor or in the most
        recent call to **setPattern** (). Returns the position where the
        **pattern** () matched in **str** , or -1 if no match was found.
        """
        ...

    def setPattern(self, pattern: QByteArray) -> None:
        """
        https://doc.qt.io/qt-6/qbytearraymatcher.html#setPattern

        **void QByteArrayMatcher::setPattern(const QByteArray & pattern )**

        Sets the byte array that this byte array matcher will search for to
        **pattern**.

        **See also** **pattern** () and **indexIn** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6 import QtCore


class QDropEvent(QtCore.QEvent):
    """
    https://doc.qt.io/qt-6/qdropevent.html

    **Detailed Description**

    When a widget **accepts drop events** , it will receive this event if it has
    accepted the most recent **QDragEnterEvent**  or **QDragMoveEvent**  sent to
    it.

    The drop event contains a proposed action, available from **proposedAction**
    (), for the widget to either accept or ignore. If the action can be handled
    by the widget, you should call the **acceptProposedAction** () function.
    Since the proposed action can be a combination of **Qt::DropAction**
    values, it may be useful to either select one of these values as a default
    action or ask the user to select their preferred action.

    If the proposed drop action is not suitable, perhaps because your custom
    widget does not support that action, you can replace it with any of the
    **possible drop actions**  by calling **setDropAction** () with your
    preferred action. If you set a value that is not present in the bitwise OR
    combination of values returned by **possibleActions** (), the default copy
    action will be used. Once a replacement drop action has been set, call
    **accept** () instead of **acceptProposedAction** () to complete the drop
    operation.

    The **mimeData** () function provides the data dropped on the widget in a
    **QMimeData**  object. This contains information about the MIME type of the
    data in addition to the data itself.

    **See also** **QMimeData** , **QDrag** , and **Drag and Drop** .
    """

    def __init__(
        self,
        pos: QtCore.QPointF,
        actions: QtCore.Qt.DropAction,
        data: QtCore.QMimeData,
        buttons: QtCore.Qt.MouseButton,
        modifiers: QtCore.Qt.KeyboardModifier,
        type: QtCore.QEvent.Type = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qdropevent.html#QDropEvent-2

        **QDropEvent::QDropEvent(const QPointF & pos , Qt::DropActions actions ,
        const QMimeData * data , Qt::MouseButtons buttons ,
        Qt::KeyboardModifiers modifiers , QEvent::Type type = Drop)**

        Constructs a drop event of a certain **type** corresponding to a drop at
        the point specified by **pos** in the destination widget's coordinate
        system.

        The **actions** indicate which types of drag and drop operation can be
        performed, and the drag data is stored as MIME-encoded data in **data**.

        The states of the mouse buttons and keyboard modifiers at the time of
        the drop are specified by **buttons** and **modifiers**.
        """
        ...

    def clone(self) -> "QDropEvent":
        ...

    def modifiers(self) -> QtCore.Qt.KeyboardModifier:
        ...

    def buttons(self) -> QtCore.Qt.MouseButton:
        ...

    def position(self) -> QtCore.QPointF:
        ...

    def mimeData(self) -> QtCore.QMimeData:
        """
        https://doc.qt.io/qt-6/qdropevent.html#mimeData

        **const QMimeData *QDropEvent::mimeData() const**

        Returns the data that was dropped on the widget and its associated MIME
        type information.
        """
        ...

    def source(self) -> QtCore.QObject:
        """
        https://doc.qt.io/qt-6/qdropevent.html#source

        **QObject *QDropEvent::source() const**

        If the source of the drag operation is a widget in this application,
        this function returns that source; otherwise it returns `nullptr`. The
        source of the operation is the first parameter to the **QDrag**  object
        used instantiate the drag.

        This is useful if your widget needs special behavior when dragging to
        itself.

        **See also** **QDrag::QDrag** ().
        """
        ...

    def setDropAction(self, action: QtCore.Qt.DropAction) -> None:
        """
        https://doc.qt.io/qt-6/qdropevent.html#setDropAction

        **void QDropEvent::setDropAction(Qt::DropAction action )**

        Sets the **action** to be performed on the data by the target. Use this
        to override the **proposed action**  with one of the **possible
        actions** .

        If you set a drop action that is not one of the possible actions, the
        drag and drop operation will default to a copy operation.

        Once you have supplied a replacement drop action, call **accept** ()
        instead of **acceptProposedAction** ().

        **See also** **dropAction** ().
        """
        ...

    def dropAction(self) -> QtCore.Qt.DropAction:
        """
        https://doc.qt.io/qt-6/qdropevent.html#dropAction

        **Qt::DropAction QDropEvent::dropAction() const**

        Returns the action to be performed on the data by the target. This may
        be different from the action supplied in **proposedAction** () if you
        have called **setDropAction** () to explicitly choose a drop action.

        **See also** **setDropAction** ().
        """
        ...

    def acceptProposedAction(self) -> None:
        """
        https://doc.qt.io/qt-6/qdropevent.html#acceptProposedAction

        **void QDropEvent::acceptProposedAction()**

        Sets the drop action to be the proposed action.

        **See also** **setDropAction** (), **proposedAction** (), and **accept**
        ().
        """
        ...

    def proposedAction(self) -> QtCore.Qt.DropAction:
        """
        https://doc.qt.io/qt-6/qdropevent.html#proposedAction

        **Qt::DropAction QDropEvent::proposedAction() const**

        Returns the proposed drop action.

        **See also** **dropAction** ().
        """
        ...

    def possibleActions(self) -> QtCore.Qt.DropAction:
        """
        https://doc.qt.io/qt-6/qdropevent.html#possibleActions

        **Qt::DropActions QDropEvent::possibleActions() const**

        Returns an OR-combination of possible drop actions.

        **See also** **dropAction** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip


class QXmlStreamEntityDeclaration(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qxmlstreamentitydeclaration.html

    **Detailed Description**

    An entity declaration consists of a **name** (), a **notationName** (), a
    **systemId** (), a **publicId** (), and a **value** ().
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qxmlstreamentitydeclaration.html#QXmlStreamEntity
        Declaration

        **QXmlStreamEntityDeclaration::QXmlStreamEntityDeclaration()**

        Creates an empty entity declaration.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QXmlStreamEntityDeclaration") -> None:
        """
        https://doc.qt.io/qt-6/qxmlstreamentitydeclaration.html#QXmlStreamEntity
        Declaration

        **QXmlStreamEntityDeclaration::QXmlStreamEntityDeclaration()**

        Creates an empty entity declaration.
        """
        ...

    def value(self) -> str:
        """
        https://doc.qt.io/qt-6/qxmlstreamentitydeclaration.html#value

        **QStringView QXmlStreamEntityDeclaration::value() const**

        Returns the entity's value.
        """
        ...

    def publicId(self) -> str:
        """
        https://doc.qt.io/qt-6/qxmlstreamentitydeclaration.html#publicId

        **QStringView QXmlStreamEntityDeclaration::publicId() const**

        Returns the public identifier.
        """
        ...

    def systemId(self) -> str:
        """
        https://doc.qt.io/qt-6/qxmlstreamentitydeclaration.html#systemId

        **QStringView QXmlStreamEntityDeclaration::systemId() const**

        Returns the system identifier.
        """
        ...

    def notationName(self) -> str:
        """
        https://doc.qt.io/qt-6/qxmlstreamentitydeclaration.html#notationName

        **QStringView QXmlStreamEntityDeclaration::notationName() const**

        Returns the notation name.
        """
        ...

    def name(self) -> str:
        """
        https://doc.qt.io/qt-6/qxmlstreamentitydeclaration.html#name

        **QStringView QXmlStreamEntityDeclaration::name() const**

        Returns the entity name.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6 import QtCore


class QHelpEvent(QtCore.QEvent):
    """
    https://doc.qt.io/qt-6/qhelpevent.html

    **Detailed Description**

    This event can be intercepted in applications to provide tooltips or "What's
    This?" help for custom widgets. The **type** () can be either
    **QEvent::ToolTip**  or **QEvent::WhatsThis** .

    **See also** **QToolTip** , **QWhatsThis** , **QStatusTipEvent** , and
    **QWhatsThisClickedEvent** .
    """

    def __init__(
        self, type: QtCore.QEvent.Type, pos: QtCore.QPoint, globalPos: QtCore.QPoint
    ) -> None:
        """
        https://doc.qt.io/qt-6/qhelpevent.html#QHelpEvent-2

        **QHelpEvent::QHelpEvent(QEvent::Type type , const QPoint & pos , const
        QPoint & globalPos )**

        Constructs a help event with the given **type** corresponding to the
        widget-relative position specified by **pos** and the global position
        specified by **globalPos**.

        **type** must be either **QEvent::ToolTip**  or **QEvent::WhatsThis** .

        **See also** **pos** () and **globalPos** ().
        """
        ...

    def clone(self) -> "QHelpEvent":
        ...

    def globalPos(self) -> QtCore.QPoint:
        """
        https://doc.qt.io/qt-6/qhelpevent.html#globalPos

        **const QPoint &QHelpEvent::globalPos() const**

        Returns the mouse cursor position when the event was generated in global
        coordinates.

        **See also** **pos** (), **globalX** (), and **globalY** ().
        """
        ...

    def pos(self) -> QtCore.QPoint:
        """
        https://doc.qt.io/qt-6/qhelpevent.html#pos

        **const QPoint &QHelpEvent::pos() const**

        Returns the mouse cursor position when the event was generated, relative
        to the widget to which the event is dispatched.

        **See also** **globalPos** (), **x** (), and **y** ().
        """
        ...

    def globalY(self) -> int:
        """
        https://doc.qt.io/qt-6/qhelpevent.html#globalY

        **int QHelpEvent::globalY() const**

        Same as **globalPos** ().**y** ().

        **See also** **y** (), **globalX** (), and **globalPos** ().
        """
        ...

    def globalX(self) -> int:
        """
        https://doc.qt.io/qt-6/qhelpevent.html#globalX

        **int QHelpEvent::globalX() const**

        Same as **globalPos** ().**x** ().

        **See also** **x** (), **globalY** (), and **globalPos** ().
        """
        ...

    def y(self) -> int:
        """
        https://doc.qt.io/qt-6/qhelpevent.html#y

        **int QHelpEvent::y() const**

        Same as **pos** ().y().

        **See also** **x** (), **pos** (), and **globalPos** ().
        """
        ...

    def x(self) -> int:
        """
        https://doc.qt.io/qt-6/qhelpevent.html#x

        **int QHelpEvent::x() const**

        Same as **pos** ().x().

        **See also** **y** (), **pos** (), and **globalPos** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QToolTip(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qtooltip.html

    **Detailed Description**

    The tip is a short piece of text reminding the user of the widget's
    function. It is drawn immediately below the given position in a distinctive
    black-on-yellow color combination. The tip can be any **rich text**
    formatted string.

    Rich text displayed in a tool tip is implicitly word-wrapped unless
    specified differently with `<p style='white-space:pre'>`.

    The simplest and most common way to set a widget's tool tip is by calling
    its **QWidget::setToolTip** () function.

    It is also possible to show different tool tips for different regions of a
    widget, by using a **QHelpEvent**  of type **QEvent::ToolTip** . Intercept
    the help event in your widget's **event** () function and call
    **QToolTip::showText** () with the text you want to display. The
    **Tooltips**  example illustrates this technique.

    If you are calling **QToolTip::hideText** (), or **QToolTip::showText** ()
    with an empty string, as a result of a **ToolTip** -event you should also
    call **ignore** () on the event, to signal that you don't want to start any
    tooltip specific modes.

    Note that, if you want to show tooltips in an item view, the model/view
    architecture provides functionality to set an item's tool tip; e.g., the
    **QTableWidgetItem::setToolTip** () function. However, if you want to
    provide custom tool tips in an item view, you must intercept the help event
    in the **QAbstractItemView::viewportEvent** () function and handle it
    yourself.

    The default tool tip color and font can be customized with **setPalette** ()
    and **setFont** (). When a tooltip is currently on display, **isVisible** ()
    returns `true` and **text** () the currently visible text.

    **Note:** Tool tips use the inactive color group of **QPalette** , because
    tool tips are not active windows.

    **See also** **QWidget::toolTip** , **QAction::toolTip** , and **Tool Tips
    Example** .
    """

    def __init__(self, a0: "QToolTip") -> None:
        ...

    @staticmethod
    def text() -> str:
        """
        https://doc.qt.io/qt-6/qtooltip.html#text

        **[static] QString QToolTip::text()**

        Returns the tooltip text, if a tooltip is visible, or an empty string if
        a tooltip is not visible.
        """
        ...

    @staticmethod
    def isVisible() -> bool:
        """
        https://doc.qt.io/qt-6/qtooltip.html#isVisible

        **[static] bool QToolTip::isVisible()**

        Returns `true` if a tooltip is currently shown.

        **See also** **showText** ().
        """
        ...

    @staticmethod
    def setFont(a0: QtGui.QFont) -> None:
        """
        https://doc.qt.io/qt-6/qtooltip.html#setFont

        **[static] void QToolTip::setFont(const QFont & font )**

        Sets the **font** used to render tooltips.

        **See also** **font** ().
        """
        ...

    @staticmethod
    def font() -> QtGui.QFont:
        """
        https://doc.qt.io/qt-6/qtooltip.html#font

        **[static] QFont QToolTip::font()**

        Returns the font used to render tooltips.

        **See also** **setFont** ().
        """
        ...

    @staticmethod
    def setPalette(a0: QtGui.QPalette) -> None:
        """
        https://doc.qt.io/qt-6/qtooltip.html#setPalette

        **[static] void QToolTip::setPalette(const QPalette & palette )**

        Sets the **palette** used to render tooltips.

        **Note:** Tool tips use the inactive color group of **QPalette** ,
        because tool tips are not active windows.

        **See also** **palette** ().
        """
        ...

    @staticmethod
    def hideText() -> None:
        """
        https://doc.qt.io/qt-6/qtooltip.html#hideText

        **[static] void QToolTip::hideText()**

        Hides the tool tip. This is the same as calling **showText** () with an
        empty string.

        **See also** **showText** ().
        """
        ...

    @staticmethod
    def palette() -> QtGui.QPalette:
        """
        https://doc.qt.io/qt-6/qtooltip.html#palette

        **[static] QPalette QToolTip::palette()**

        Returns the palette used to render tooltips.

        **Note:** Tool tips use the inactive color group of **QPalette** ,
        because tool tips are not active windows.

        **See also** **setPalette** ().
        """
        ...

    @staticmethod
    def showText(
        pos: QtCore.QPoint,
        text: str,
        widget: typing.Optional[QWidget] = ...,
        rect: QtCore.QRect = ...,
        msecShowTime: int = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtooltip.html#showText

        **[static] void QToolTip::showText(const QPoint & pos , const QString &
        text , QWidget * w = nullptr, const QRect & rect = {}, int
        msecDisplayTime = -1)**

        Shows **text** as a tool tip, with the global position **pos** as the
        point of interest. The tool tip will be shown with a platform specific
        offset from this point of interest.

        If you specify a non-empty rect the tip will be hidden as soon as you
        move your cursor out of this area.

        The **rect** is in the coordinates of the widget you specify with **w**.
        If the **rect** is not empty you must specify a widget. Otherwise this
        argument can be `nullptr` but it is used to determine the appropriate
        screen on multi-head systems.

        The **msecDisplayTime** parameter specifies for how long the tool tip
        will be displayed, in milliseconds. With the default value of -1, the
        time is based on the length of the text.

        If **text** is empty the tool tip is hidden. If the text is the same as
        the currently shown tooltip, the tip will **not** move. You can force
        moving by first hiding the tip with an empty text, and then showing the
        new tip at the new position.
        """
        ...
